# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto\x12\x34github.com.metaprov.modelaapi.services.webrequest.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd2\x01\n\x16ListWebRequestsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x17ListWebRequestsResponse\x12Y\n\x0bwebrequests\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18\x43reateWebRequestResponse\"o\n\x17\x43reateWebRequestRequest\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x9f\x01\n\x17UpdateWebRequestRequest\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateWebRequestResponse\"7\n\x14GetWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetWebRequestResponse\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteWebRequestResponse\"l\n\x14RunWebRequestRequest\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x17\n\x15RunWebRequestResponse2\xfe\n\n\x11WebRequestService\x12\xd3\x01\n\x0fListWebRequests\x12L.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest\x1aM.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/webrequests/{namespace}\x12\xcd\x01\n\x10\x43reateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webrequests:\x01*\x12\xd4\x01\n\rGetWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/webrequests/{namespace}/{name}\x12\x88\x02\n\x10UpdateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/webrequests/{namespace}/{name}\x12\x80\x02\n\rRunWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse\"V\x82\xd3\xe4\x93\x02P\"N/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:runB6Z4github.com/metaprov/modelaapi/services/webrequest/v1b\x06proto3')



_LISTWEBREQUESTSREQUEST = DESCRIPTOR.message_types_by_name['ListWebRequestsRequest']
_LISTWEBREQUESTSREQUEST_LABELSENTRY = _LISTWEBREQUESTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTWEBREQUESTSRESPONSE = DESCRIPTOR.message_types_by_name['ListWebRequestsResponse']
_CREATEWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['CreateWebRequestResponse']
_CREATEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['CreateWebRequestRequest']
_UPDATEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebRequestRequest']
_UPDATEWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateWebRequestResponse']
_GETWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['GetWebRequestRequest']
_GETWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['GetWebRequestResponse']
_DELETEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['DeleteWebRequestRequest']
_DELETEWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteWebRequestResponse']
_RUNWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['RunWebRequestRequest']
_RUNWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['RunWebRequestResponse']
ListWebRequestsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestsRequest)
_sym_db.RegisterMessage(ListWebRequestsRequest.LabelsEntry)

ListWebRequestsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestsResponse)

CreateWebRequestResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestResponse)

CreateWebRequestRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRequest)

UpdateWebRequestRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRequest)

UpdateWebRequestResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestResponse)

GetWebRequestRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRequest)

GetWebRequestResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse)
  })
_sym_db.RegisterMessage(GetWebRequestResponse)

DeleteWebRequestRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRequest)

DeleteWebRequestResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestResponse)

RunWebRequestRequest = _reflection.GeneratedProtocolMessageType('RunWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest)
  })
_sym_db.RegisterMessage(RunWebRequestRequest)

RunWebRequestResponse = _reflection.GeneratedProtocolMessageType('RunWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse)
  })
_sym_db.RegisterMessage(RunWebRequestResponse)

_WEBREQUESTSERVICE = DESCRIPTOR.services_by_name['WebRequestService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/webrequest/v1'
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._options = None
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _WEBREQUESTSERVICE.methods_by_name['ListWebRequests']._options = None
  _WEBREQUESTSERVICE.methods_by_name['ListWebRequests']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/webrequests/{namespace}'
  _WEBREQUESTSERVICE.methods_by_name['CreateWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['CreateWebRequest']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/webrequests:\001*'
  _WEBREQUESTSERVICE.methods_by_name['GetWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['GetWebRequest']._serialized_options = b'\202\323\344\223\002$\022\"/v1/webrequests/{namespace}/{name}'
  _WEBREQUESTSERVICE.methods_by_name['UpdateWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['UpdateWebRequest']._serialized_options = b'\202\323\344\223\002O\032J/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:\001*'
  _WEBREQUESTSERVICE.methods_by_name['DeleteWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['DeleteWebRequest']._serialized_options = b'\202\323\344\223\002$*\"/v1/webrequests/{namespace}/{name}'
  _WEBREQUESTSERVICE.methods_by_name['RunWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['RunWebRequest']._serialized_options = b'\202\323\344\223\002P\"N/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:run'
  _LISTWEBREQUESTSREQUEST._serialized_start=262
  _LISTWEBREQUESTSREQUEST._serialized_end=472
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._serialized_start=427
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._serialized_end=472
  _LISTWEBREQUESTSRESPONSE._serialized_start=475
  _LISTWEBREQUESTSRESPONSE._serialized_end=616
  _CREATEWEBREQUESTRESPONSE._serialized_start=618
  _CREATEWEBREQUESTRESPONSE._serialized_end=644
  _CREATEWEBREQUESTREQUEST._serialized_start=646
  _CREATEWEBREQUESTREQUEST._serialized_end=757
  _UPDATEWEBREQUESTREQUEST._serialized_start=760
  _UPDATEWEBREQUESTREQUEST._serialized_end=919
  _UPDATEWEBREQUESTRESPONSE._serialized_start=921
  _UPDATEWEBREQUESTRESPONSE._serialized_end=947
  _GETWEBREQUESTREQUEST._serialized_start=949
  _GETWEBREQUESTREQUEST._serialized_end=1004
  _GETWEBREQUESTRESPONSE._serialized_start=1006
  _GETWEBREQUESTRESPONSE._serialized_end=1129
  _DELETEWEBREQUESTREQUEST._serialized_start=1131
  _DELETEWEBREQUESTREQUEST._serialized_end=1189
  _DELETEWEBREQUESTRESPONSE._serialized_start=1191
  _DELETEWEBREQUESTRESPONSE._serialized_end=1217
  _RUNWEBREQUESTREQUEST._serialized_start=1219
  _RUNWEBREQUESTREQUEST._serialized_end=1327
  _RUNWEBREQUESTRESPONSE._serialized_start=1329
  _RUNWEBREQUESTRESPONSE._serialized_end=1352
  _WEBREQUESTSERVICE._serialized_start=1355
  _WEBREQUESTSERVICE._serialized_end=2761
# @@protoc_insertion_point(module_scope)
