# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/system/v1/system.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/system/v1/system.proto',
  package='github.com.metaprov.modelaapi.services.servingsite.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/servingsite/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=github.com/metaprov/modelaapi/services/system/v1/system.proto\x12\x35github.com.metaprov.modelaapi.services.servingsite.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"6\n\x16\x44ownloadLogFileRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\")\n\x17\x44ownloadLogFileResponse\x12\x0e\n\x06result\x18\x01 \x01(\x0c\"5\n\x15\x42\x61\x63kupDatabaseRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"&\n\x16\x42\x61\x63kupDatabaseResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"1\n\x11\x42\x61\x63kupEtcdRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\"\n\x12\x42\x61\x63kupEtcdResponse\x12\x0c\n\x04path\x18\x01 \x01(\t2\xda\x04\n\rSystemService\x12\xc6\x01\n\x0f\x44ownloadLogfile\x12M.github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest\x1aN.github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/download\x12\xc3\x01\n\x0e\x42\x61\x63kupDatabase\x12L.github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest\x1aM.github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/v1/backupdb\x12\xb9\x01\n\nBackupEtcd\x12H.github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest\x1aI.github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0e/v1/backupetcdB7Z5github.com/metaprov/modelaapi/services/servingsite/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_DOWNLOADLOGFILEREQUEST = _descriptor.Descriptor(
  name='DownloadLogFileRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=275,
)


_DOWNLOADLOGFILERESPONSE = _descriptor.Descriptor(
  name='DownloadLogFileResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse.result', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=318,
)


_BACKUPDATABASEREQUEST = _descriptor.Descriptor(
  name='BackupDatabaseRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=373,
)


_BACKUPDATABASERESPONSE = _descriptor.Descriptor(
  name='BackupDatabaseResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=413,
)


_BACKUPETCDREQUEST = _descriptor.Descriptor(
  name='BackupEtcdRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=464,
)


_BACKUPETCDRESPONSE = _descriptor.Descriptor(
  name='BackupEtcdResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=500,
)

DESCRIPTOR.message_types_by_name['DownloadLogFileRequest'] = _DOWNLOADLOGFILEREQUEST
DESCRIPTOR.message_types_by_name['DownloadLogFileResponse'] = _DOWNLOADLOGFILERESPONSE
DESCRIPTOR.message_types_by_name['BackupDatabaseRequest'] = _BACKUPDATABASEREQUEST
DESCRIPTOR.message_types_by_name['BackupDatabaseResponse'] = _BACKUPDATABASERESPONSE
DESCRIPTOR.message_types_by_name['BackupEtcdRequest'] = _BACKUPETCDREQUEST
DESCRIPTOR.message_types_by_name['BackupEtcdResponse'] = _BACKUPETCDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DownloadLogFileRequest = _reflection.GeneratedProtocolMessageType('DownloadLogFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest)
  })
_sym_db.RegisterMessage(DownloadLogFileRequest)

DownloadLogFileResponse = _reflection.GeneratedProtocolMessageType('DownloadLogFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse)
  })
_sym_db.RegisterMessage(DownloadLogFileResponse)

BackupDatabaseRequest = _reflection.GeneratedProtocolMessageType('BackupDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest)
  })
_sym_db.RegisterMessage(BackupDatabaseRequest)

BackupDatabaseResponse = _reflection.GeneratedProtocolMessageType('BackupDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse)
  })
_sym_db.RegisterMessage(BackupDatabaseResponse)

BackupEtcdRequest = _reflection.GeneratedProtocolMessageType('BackupEtcdRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest)
  })
_sym_db.RegisterMessage(BackupEtcdRequest)

BackupEtcdResponse = _reflection.GeneratedProtocolMessageType('BackupEtcdResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse)
  })
_sym_db.RegisterMessage(BackupEtcdResponse)


DESCRIPTOR._options = None

_SYSTEMSERVICE = _descriptor.ServiceDescriptor(
  name='SystemService',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=503,
  serialized_end=1105,
  methods=[
  _descriptor.MethodDescriptor(
    name='DownloadLogfile',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService.DownloadLogfile',
    index=0,
    containing_service=None,
    input_type=_DOWNLOADLOGFILEREQUEST,
    output_type=_DOWNLOADLOGFILERESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/download',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BackupDatabase',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService.BackupDatabase',
    index=1,
    containing_service=None,
    input_type=_BACKUPDATABASEREQUEST,
    output_type=_BACKUPDATABASERESPONSE,
    serialized_options=b'\202\323\344\223\002\016\"\014/v1/backupdb',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BackupEtcd',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService.BackupEtcd',
    index=2,
    containing_service=None,
    input_type=_BACKUPETCDREQUEST,
    output_type=_BACKUPETCDRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\016/v1/backupetcd',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SYSTEMSERVICE)

DESCRIPTOR.services_by_name['SystemService'] = _SYSTEMSERVICE

# @@protoc_insertion_point(module_scope)
