# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto\x12\x32github.com.metaprov.modelaapi.services.apitoken.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\xf7\x01\n\x14ListApiTokensRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x15ListApiTokensResponse\x12V\n\tapitokens\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiTokenList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x12\n\x10\x41piTokenResponse\"|\n\x15\x43reateApiTokenRequest\x12Q\n\x08\x61pitoken\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x10\n\x08password\x18\x02 \x01(\t\"\x18\n\x16\x43reateApiTokenResponse\"\x9b\x01\n\x15UpdateApiTokenRequest\x12Q\n\x08\x61pitoken\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x18\n\x16UpdateApiTokenResponse\"5\n\x12GetApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x13GetApiTokenResponse\x12Q\n\x08\x61pitoken\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1cGetApiTokenNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x1dGetApiTokenNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"8\n\x15\x44\x65leteApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteApiTokenResponse\"\x18\n\x16\x41piTokenCreateResponse\"I\n\x14\x41piTokenLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"&\n\x15\x41piTokenLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t2\xb9\x08\n\x0f\x41piTokenService\x12\xc7\x01\n\rListApiTokens\x12H.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest\x1aI.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/apitokens/{namespace}\x12\xc1\x01\n\x0e\x43reateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/apitokens:\x01*\x12\xc8\x01\n\x0bGetApiToken\x12\x46.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest\x1aG.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/apitokens/{namespace}/{name}\x12\xf8\x01\n\x0eUpdateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse\"O\x82\xd3\xe4\x93\x02I\x1a\x44/v1/apitokens/{apitoken.metadata.namespace}/{apitoken.metadata.name}:\x01*\x12\xd1\x01\n\x0e\x44\x65leteApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse\"(\x82\xd3\xe4\x93\x02\"* /v1/apitokens/{namespace}/{name}B4Z2github.com/metaprov/modelaapi/services/apitoken/v1b\x06proto3')



_LISTAPITOKENSREQUEST = DESCRIPTOR.message_types_by_name['ListApiTokensRequest']
_LISTAPITOKENSREQUEST_LABELSENTRY = _LISTAPITOKENSREQUEST.nested_types_by_name['LabelsEntry']
_LISTAPITOKENSRESPONSE = DESCRIPTOR.message_types_by_name['ListApiTokensResponse']
_APITOKENRESPONSE = DESCRIPTOR.message_types_by_name['ApiTokenResponse']
_CREATEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['CreateApiTokenRequest']
_CREATEAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['CreateApiTokenResponse']
_UPDATEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['UpdateApiTokenRequest']
_UPDATEAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['UpdateApiTokenResponse']
_GETAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['GetApiTokenRequest']
_GETAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['GetApiTokenResponse']
_GETAPITOKENNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesRequest']
_GETAPITOKENNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesResponse']
_DELETEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['DeleteApiTokenRequest']
_DELETEAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['DeleteApiTokenResponse']
_APITOKENCREATERESPONSE = DESCRIPTOR.message_types_by_name['ApiTokenCreateResponse']
_APITOKENLOGINREQUEST = DESCRIPTOR.message_types_by_name['ApiTokenLoginRequest']
_APITOKENLOGINRESPONSE = DESCRIPTOR.message_types_by_name['ApiTokenLoginResponse']
ListApiTokensRequest = _reflection.GeneratedProtocolMessageType('ListApiTokensRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTAPITOKENSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTAPITOKENSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest)
  })
_sym_db.RegisterMessage(ListApiTokensRequest)
_sym_db.RegisterMessage(ListApiTokensRequest.LabelsEntry)

ListApiTokensResponse = _reflection.GeneratedProtocolMessageType('ListApiTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse)
  })
_sym_db.RegisterMessage(ListApiTokensResponse)

ApiTokenResponse = _reflection.GeneratedProtocolMessageType('ApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenResponse)
  })
_sym_db.RegisterMessage(ApiTokenResponse)

CreateApiTokenRequest = _reflection.GeneratedProtocolMessageType('CreateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest)
  })
_sym_db.RegisterMessage(CreateApiTokenRequest)

CreateApiTokenResponse = _reflection.GeneratedProtocolMessageType('CreateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse)
  })
_sym_db.RegisterMessage(CreateApiTokenResponse)

UpdateApiTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest)
  })
_sym_db.RegisterMessage(UpdateApiTokenRequest)

UpdateApiTokenResponse = _reflection.GeneratedProtocolMessageType('UpdateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse)
  })
_sym_db.RegisterMessage(UpdateApiTokenResponse)

GetApiTokenRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest)
  })
_sym_db.RegisterMessage(GetApiTokenRequest)

GetApiTokenResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse)
  })
_sym_db.RegisterMessage(GetApiTokenResponse)

GetApiTokenNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesRequest)

GetApiTokenNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesResponse)

DeleteApiTokenRequest = _reflection.GeneratedProtocolMessageType('DeleteApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest)
  })
_sym_db.RegisterMessage(DeleteApiTokenRequest)

DeleteApiTokenResponse = _reflection.GeneratedProtocolMessageType('DeleteApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse)
  })
_sym_db.RegisterMessage(DeleteApiTokenResponse)

ApiTokenCreateResponse = _reflection.GeneratedProtocolMessageType('ApiTokenCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenCreateResponse)
  })
_sym_db.RegisterMessage(ApiTokenCreateResponse)

ApiTokenLoginRequest = _reflection.GeneratedProtocolMessageType('ApiTokenLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest)
  })
_sym_db.RegisterMessage(ApiTokenLoginRequest)

ApiTokenLoginResponse = _reflection.GeneratedProtocolMessageType('ApiTokenLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse)
  })
_sym_db.RegisterMessage(ApiTokenLoginResponse)

_APITOKENSERVICE = DESCRIPTOR.services_by_name['ApiTokenService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/apitoken/v1'
  _LISTAPITOKENSREQUEST_LABELSENTRY._options = None
  _LISTAPITOKENSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _APITOKENSERVICE.methods_by_name['ListApiTokens']._options = None
  _APITOKENSERVICE.methods_by_name['ListApiTokens']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/apitokens/{namespace}'
  _APITOKENSERVICE.methods_by_name['CreateApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['CreateApiToken']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/apitokens:\001*'
  _APITOKENSERVICE.methods_by_name['GetApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['GetApiToken']._serialized_options = b'\202\323\344\223\002\"\022 /v1/apitokens/{namespace}/{name}'
  _APITOKENSERVICE.methods_by_name['UpdateApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['UpdateApiToken']._serialized_options = b'\202\323\344\223\002I\032D/v1/apitokens/{apitoken.metadata.namespace}/{apitoken.metadata.name}:\001*'
  _APITOKENSERVICE.methods_by_name['DeleteApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['DeleteApiToken']._serialized_options = b'\202\323\344\223\002\"* /v1/apitokens/{namespace}/{name}'
  _LISTAPITOKENSREQUEST._serialized_start=320
  _LISTAPITOKENSREQUEST._serialized_end=567
  _LISTAPITOKENSREQUEST_LABELSENTRY._serialized_start=522
  _LISTAPITOKENSREQUEST_LABELSENTRY._serialized_end=567
  _LISTAPITOKENSRESPONSE._serialized_start=570
  _LISTAPITOKENSRESPONSE._serialized_end=706
  _APITOKENRESPONSE._serialized_start=708
  _APITOKENRESPONSE._serialized_end=726
  _CREATEAPITOKENREQUEST._serialized_start=728
  _CREATEAPITOKENREQUEST._serialized_end=852
  _CREATEAPITOKENRESPONSE._serialized_start=854
  _CREATEAPITOKENRESPONSE._serialized_end=878
  _UPDATEAPITOKENREQUEST._serialized_start=881
  _UPDATEAPITOKENREQUEST._serialized_end=1036
  _UPDATEAPITOKENRESPONSE._serialized_start=1038
  _UPDATEAPITOKENRESPONSE._serialized_end=1062
  _GETAPITOKENREQUEST._serialized_start=1064
  _GETAPITOKENREQUEST._serialized_end=1117
  _GETAPITOKENRESPONSE._serialized_start=1119
  _GETAPITOKENRESPONSE._serialized_end=1237
  _GETAPITOKENNAMESPACESREQUEST._serialized_start=1239
  _GETAPITOKENNAMESPACESREQUEST._serialized_end=1302
  _GETAPITOKENNAMESPACESRESPONSE._serialized_start=1304
  _GETAPITOKENNAMESPACESRESPONSE._serialized_end=1420
  _DELETEAPITOKENREQUEST._serialized_start=1422
  _DELETEAPITOKENREQUEST._serialized_end=1478
  _DELETEAPITOKENRESPONSE._serialized_start=1480
  _DELETEAPITOKENRESPONSE._serialized_end=1504
  _APITOKENCREATERESPONSE._serialized_start=1506
  _APITOKENCREATERESPONSE._serialized_end=1530
  _APITOKENLOGINREQUEST._serialized_start=1532
  _APITOKENLOGINREQUEST._serialized_end=1605
  _APITOKENLOGINRESPONSE._serialized_start=1607
  _APITOKENLOGINRESPONSE._serialized_end=1645
  _APITOKENSERVICE._serialized_start=1648
  _APITOKENSERVICE._serialized_end=2729
# @@protoc_insertion_point(module_scope)
