# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto\x12\x35github.com.metaprov.modelaapi.services.notebookrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\x80\x02\n\x17ListNotebookRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x01\n\x18ListNotebookRunsResponse\x12_\n\x0cnotebookruns\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x15\n\x13NotebookRunResponse\"v\n\x18\x43reateNotebookRunRequest\x12Z\n\x0bnotebookrun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x1b\n\x19\x43reateNotebookRunResponse\"\xa6\x01\n\x18UpdateNotebookRunRequest\x12Z\n\x0bnotebookrun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1b\n\x19UpdateNotebookRunResponse\"8\n\x15GetNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x16GetNotebookRunResponse\x12Y\n\nnotbookrun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteNotebookRunResponse2\x9c\t\n\x12NotebookRunService\x12\xd9\x01\n\x10ListNotebookRuns\x12N.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest\x1aO.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/notebookruns/{namespace}\x12\xd3\x01\n\x11\x43reateNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/notebookruns:\x01*\x12\xda\x01\n\x0eGetNotebookRun\x12L.github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest\x1aM.github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/notebookruns/{namespace}/{name}\x12\x90\x02\n\x11UpdateNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse\"X\x82\xd3\xe4\x93\x02R\x1aM/v1/notebookruns/{notebookrun.metadata.namespace}/{notebookrun.metadata.name}:\x01*\x12\xe3\x01\n\x11\x44\x65leteNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse\"+\x82\xd3\xe4\x93\x02%*#/v1/notebookruns/{namespace}/{name}B7Z5github.com/metaprov/modelaapi/services/notebookrun/v1b\x06proto3')



_LISTNOTEBOOKRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListNotebookRunsRequest']
_LISTNOTEBOOKRUNSREQUEST_LABELSENTRY = _LISTNOTEBOOKRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTNOTEBOOKRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotebookRunsResponse']
_NOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['NotebookRunResponse']
_CREATENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateNotebookRunRequest']
_CREATENOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateNotebookRunResponse']
_UPDATENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotebookRunRequest']
_UPDATENOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateNotebookRunResponse']
_GETNOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['GetNotebookRunRequest']
_GETNOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetNotebookRunResponse']
_DELETENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotebookRunRequest']
_DELETENOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotebookRunResponse']
ListNotebookRunsRequest = _reflection.GeneratedProtocolMessageType('ListNotebookRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest)
  })
_sym_db.RegisterMessage(ListNotebookRunsRequest)
_sym_db.RegisterMessage(ListNotebookRunsRequest.LabelsEntry)

ListNotebookRunsResponse = _reflection.GeneratedProtocolMessageType('ListNotebookRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse)
  })
_sym_db.RegisterMessage(ListNotebookRunsResponse)

NotebookRunResponse = _reflection.GeneratedProtocolMessageType('NotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunResponse)
  })
_sym_db.RegisterMessage(NotebookRunResponse)

CreateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRunRequest)

CreateNotebookRunResponse = _reflection.GeneratedProtocolMessageType('CreateNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse)
  })
_sym_db.RegisterMessage(CreateNotebookRunResponse)

UpdateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRunRequest)

UpdateNotebookRunResponse = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse)
  })
_sym_db.RegisterMessage(UpdateNotebookRunResponse)

GetNotebookRunRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest)
  })
_sym_db.RegisterMessage(GetNotebookRunRequest)

GetNotebookRunResponse = _reflection.GeneratedProtocolMessageType('GetNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse)
  })
_sym_db.RegisterMessage(GetNotebookRunResponse)

DeleteNotebookRunRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRunRequest)

DeleteNotebookRunResponse = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse)
  })
_sym_db.RegisterMessage(DeleteNotebookRunResponse)

_NOTEBOOKRUNSERVICE = DESCRIPTOR.services_by_name['NotebookRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/metaprov/modelaapi/services/notebookrun/v1'
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._options = None
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKRUNSERVICE.methods_by_name['ListNotebookRuns']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['ListNotebookRuns']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/notebookruns/{namespace}'
  _NOTEBOOKRUNSERVICE.methods_by_name['CreateNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['CreateNotebookRun']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/notebookruns:\001*'
  _NOTEBOOKRUNSERVICE.methods_by_name['GetNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['GetNotebookRun']._serialized_options = b'\202\323\344\223\002%\022#/v1/notebookruns/{namespace}/{name}'
  _NOTEBOOKRUNSERVICE.methods_by_name['UpdateNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['UpdateNotebookRun']._serialized_options = b'\202\323\344\223\002R\032M/v1/notebookruns/{notebookrun.metadata.namespace}/{notebookrun.metadata.name}:\001*'
  _NOTEBOOKRUNSERVICE.methods_by_name['DeleteNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['DeleteNotebookRun']._serialized_options = b'\202\323\344\223\002%*#/v1/notebookruns/{namespace}/{name}'
  _LISTNOTEBOOKRUNSREQUEST._serialized_start=332
  _LISTNOTEBOOKRUNSREQUEST._serialized_end=588
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._serialized_start=543
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._serialized_end=588
  _LISTNOTEBOOKRUNSRESPONSE._serialized_start=591
  _LISTNOTEBOOKRUNSRESPONSE._serialized_end=739
  _NOTEBOOKRUNRESPONSE._serialized_start=741
  _NOTEBOOKRUNRESPONSE._serialized_end=762
  _CREATENOTEBOOKRUNREQUEST._serialized_start=764
  _CREATENOTEBOOKRUNREQUEST._serialized_end=882
  _CREATENOTEBOOKRUNRESPONSE._serialized_start=884
  _CREATENOTEBOOKRUNRESPONSE._serialized_end=911
  _UPDATENOTEBOOKRUNREQUEST._serialized_start=914
  _UPDATENOTEBOOKRUNREQUEST._serialized_end=1080
  _UPDATENOTEBOOKRUNRESPONSE._serialized_start=1082
  _UPDATENOTEBOOKRUNRESPONSE._serialized_end=1109
  _GETNOTEBOOKRUNREQUEST._serialized_start=1111
  _GETNOTEBOOKRUNREQUEST._serialized_end=1167
  _GETNOTEBOOKRUNRESPONSE._serialized_start=1170
  _GETNOTEBOOKRUNRESPONSE._serialized_end=1299
  _DELETENOTEBOOKRUNREQUEST._serialized_start=1301
  _DELETENOTEBOOKRUNREQUEST._serialized_end=1360
  _DELETENOTEBOOKRUNRESPONSE._serialized_start=1362
  _DELETENOTEBOOKRUNRESPONSE._serialized_end=1389
  _NOTEBOOKRUNSERVICE._serialized_start=1392
  _NOTEBOOKRUNSERVICE._serialized_end=2572
# @@protoc_insertion_point(module_scope)
