# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUgithub.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto\x12<github.com.metaprov.modelaapi.services.featurepipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x93\x02\n\x1dListFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12w\n\x06labels\x18\x02 \x03(\x0b\x32g.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x1eListFeaturePipelineRunResponse\x12i\n\x13\x66\x65\x61turepipelineruns\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x87\x01\n\x1f\x43reateFeaturePipelineRunRequest\x12\x64\n\x12\x66\x65\x61turepipelinerun\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\"\n CreateFeaturePipelineRunResponse\"\xb7\x01\n\x1fUpdateFeaturePipelineRunRequest\x12\x64\n\x12\x66\x65\x61turepipelinerun\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\"\n UpdateFeaturePipelineRunResponse\"?\n\x1cGetFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x93\x01\n\x1dGetFeaturePipelineRunResponse\x12\x64\n\x12\x66\x65\x61turepipelinerun\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"B\n\x1f\x44\x65leteFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n DeleteFeaturePipelineRunResponse2\xfa\n\n\x19\x46\x65\x61turePipelineRunService\x12\x81\x02\n\x17ListFeaturePipelineRuns\x12[.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest\x1a\\.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/featurepipelineruns/{namespace}\x12\xfd\x01\n\x18\x43reateFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/featurepipelineruns:\x01*\x12\x84\x02\n\x15GetFeaturePipelineRun\x12Z.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest\x1a[.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse\"2\x82\xd3\xe4\x93\x02,\x12*/v1/featurepipelineruns/{namespace}/{name}\x12\xc5\x02\n\x18UpdateFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse\"j\x82\xd3\xe4\x93\x02\x64\x1a_/v1/featurepipelines/{featurepipelinerun.metadata.namespace}/{featurepipelinerun.metadata.name}:\x01*\x12\x89\x02\n\x18\x44\x65leteFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse\".\x82\xd3\xe4\x93\x02(*&/v1/featurepipeline/{namespace}/{name}B>Z<github.com/metaprov/modelaapi/services/featurepipelinerun/v1b\x06proto3')



_LISTFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunRequest']
_LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY = _LISTFEATUREPIPELINERUNREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunResponse']
_CREATEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunRequest']
_CREATEFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunResponse']
_UPDATEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunRequest']
_UPDATEFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunResponse']
_GETFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunRequest']
_GETFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunResponse']
_DELETEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunRequest']
_DELETEFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunResponse']
ListFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunRequest)
_sym_db.RegisterMessage(ListFeaturePipelineRunRequest.LabelsEntry)

ListFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunResponse)

CreateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunRequest)

CreateFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunResponse)

UpdateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunRequest)

UpdateFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunResponse)

GetFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunRequest)

GetFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunResponse)

DeleteFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunRequest)

DeleteFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunResponse)

_FEATUREPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['FeaturePipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/metaprov/modelaapi/services/featurepipelinerun/v1'
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._options = None
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['ListFeaturePipelineRuns']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['ListFeaturePipelineRuns']._serialized_options = b'\202\323\344\223\002%\022#/v1/featurepipelineruns/{namespace}'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['CreateFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['CreateFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/featurepipelineruns:\001*'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['GetFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['GetFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002,\022*/v1/featurepipelineruns/{namespace}/{name}'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['UpdateFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['UpdateFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002d\032_/v1/featurepipelines/{featurepipelinerun.metadata.namespace}/{featurepipelinerun.metadata.name}:\001*'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['DeleteFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['DeleteFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002(*&/v1/featurepipeline/{namespace}/{name}'
  _LISTFEATUREPIPELINERUNREQUEST._serialized_start=286
  _LISTFEATUREPIPELINERUNREQUEST._serialized_end=561
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._serialized_start=516
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._serialized_end=561
  _LISTFEATUREPIPELINERUNRESPONSE._serialized_start=564
  _LISTFEATUREPIPELINERUNRESPONSE._serialized_end=728
  _CREATEFEATUREPIPELINERUNREQUEST._serialized_start=731
  _CREATEFEATUREPIPELINERUNREQUEST._serialized_end=866
  _CREATEFEATUREPIPELINERUNRESPONSE._serialized_start=868
  _CREATEFEATUREPIPELINERUNRESPONSE._serialized_end=902
  _UPDATEFEATUREPIPELINERUNREQUEST._serialized_start=905
  _UPDATEFEATUREPIPELINERUNREQUEST._serialized_end=1088
  _UPDATEFEATUREPIPELINERUNRESPONSE._serialized_start=1090
  _UPDATEFEATUREPIPELINERUNRESPONSE._serialized_end=1124
  _GETFEATUREPIPELINERUNREQUEST._serialized_start=1126
  _GETFEATUREPIPELINERUNREQUEST._serialized_end=1189
  _GETFEATUREPIPELINERUNRESPONSE._serialized_start=1192
  _GETFEATUREPIPELINERUNRESPONSE._serialized_end=1339
  _DELETEFEATUREPIPELINERUNREQUEST._serialized_start=1341
  _DELETEFEATUREPIPELINERUNREQUEST._serialized_end=1407
  _DELETEFEATUREPIPELINERUNRESPONSE._serialized_start=1409
  _DELETEFEATUREPIPELINERUNRESPONSE._serialized_end=1443
  _FEATUREPIPELINERUNSERVICE._serialized_start=1446
  _FEATUREPIPELINERUNSERVICE._serialized_end=2848
# @@protoc_insertion_point(module_scope)
