# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.notebookrun.v1 import notebookrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2


class NotebookRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListNotebookRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/ListNotebookRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsResponse.FromString,
                )
        self.CreateNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/CreateNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunResponse.FromString,
                )
        self.GetNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/GetNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunResponse.FromString,
                )
        self.UpdateNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/UpdateNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunResponse.FromString,
                )
        self.DeleteNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/DeleteNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunResponse.FromString,
                )


class NotebookRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListNotebookRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotebookRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListNotebookRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNotebookRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsResponse.SerializeToString,
            ),
            'CreateNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunResponse.SerializeToString,
            ),
            'GetNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunResponse.SerializeToString,
            ),
            'UpdateNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunResponse.SerializeToString,
            ),
            'DeleteNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotebookRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListNotebookRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/ListNotebookRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/CreateNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/GetNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/UpdateNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/DeleteNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
