# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto\x12\x37github.com.metaprov.modelaapi.services.webrequestrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xdb\x01\n\x19ListWebRequestRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\x1aListWebRequestRunsResponse\x12_\n\x0ewebrequestruns\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1d\n\x1b\x43reateWebRequestRunResponse\"x\n\x1a\x43reateWebRequestRunRequest\x12Z\n\rwebrequestrun\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\xa8\x01\n\x1aUpdateWebRequestRunRequest\x12Z\n\rwebrequestrun\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateWebRequestRunResponse\":\n\x17GetWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x84\x01\n\x18GetWebRequestRunResponse\x12Z\n\rwebrequestrun\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteWebRequestRunResponse2\xd2\t\n\x14WebRequestRunService\x12\xe5\x01\n\x12ListWebRequestRuns\x12R.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest\x1aS.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/webrequestruns/{namespace}\x12\xdf\x01\n\x13\x43reateWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/webrequestruns:\x01*\x12\xda\x01\n\x10GetWebRequestRun\x12P.github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest\x1aQ.github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/webrequestruns/{name}\x12\xa0\x02\n\x13UpdateWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse\"^\x82\xd3\xe4\x93\x02X\x1aS/v1/webrequestruns/{webrequestrun.metadata.namespace}/{webrequestrun.metadata.name}:\x01*\x12\xef\x01\n\x13\x44\x65leteWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse\"-\x82\xd3\xe4\x93\x02\'*%/v1/webrequestruns/{namespace}/{name}B9Z7github.com/metaprov/modelaapi/services/webrequestrun/v1b\x06proto3')



_LISTWEBREQUESTRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListWebRequestRunsRequest']
_LISTWEBREQUESTRUNSREQUEST_LABELSENTRY = _LISTWEBREQUESTRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTWEBREQUESTRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListWebRequestRunsResponse']
_CREATEWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateWebRequestRunResponse']
_CREATEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateWebRequestRunRequest']
_UPDATEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebRequestRunRequest']
_UPDATEWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateWebRequestRunResponse']
_GETWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['GetWebRequestRunRequest']
_GETWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetWebRequestRunResponse']
_DELETEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteWebRequestRunRequest']
_DELETEWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteWebRequestRunResponse']
ListWebRequestRunsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestRunsRequest)
_sym_db.RegisterMessage(ListWebRequestRunsRequest.LabelsEntry)

ListWebRequestRunsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestRunsResponse)

CreateWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestRunResponse)

CreateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRunRequest)

UpdateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunRequest)

UpdateWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunResponse)

GetWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRunRequest)

GetWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse)
  })
_sym_db.RegisterMessage(GetWebRequestRunResponse)

DeleteWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunRequest)

DeleteWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunResponse)

_WEBREQUESTRUNSERVICE = DESCRIPTOR.services_by_name['WebRequestRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/webrequestrun/v1'
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._options = None
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _WEBREQUESTRUNSERVICE.methods_by_name['ListWebRequestRuns']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['ListWebRequestRuns']._serialized_options = b'\202\323\344\223\002 \022\036/v1/webrequestruns/{namespace}'
  _WEBREQUESTRUNSERVICE.methods_by_name['CreateWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['CreateWebRequestRun']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/webrequestruns:\001*'
  _WEBREQUESTRUNSERVICE.methods_by_name['GetWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['GetWebRequestRun']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/webrequestruns/{name}'
  _WEBREQUESTRUNSERVICE.methods_by_name['UpdateWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['UpdateWebRequestRun']._serialized_options = b'\202\323\344\223\002X\032S/v1/webrequestruns/{webrequestrun.metadata.namespace}/{webrequestrun.metadata.name}:\001*'
  _WEBREQUESTRUNSERVICE.methods_by_name['DeleteWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['DeleteWebRequestRun']._serialized_options = b'\202\323\344\223\002\'*%/v1/webrequestruns/{namespace}/{name}'
  _LISTWEBREQUESTRUNSREQUEST._serialized_start=271
  _LISTWEBREQUESTRUNSREQUEST._serialized_end=490
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._serialized_start=445
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._serialized_end=490
  _LISTWEBREQUESTRUNSRESPONSE._serialized_start=493
  _LISTWEBREQUESTRUNSRESPONSE._serialized_end=643
  _CREATEWEBREQUESTRUNRESPONSE._serialized_start=645
  _CREATEWEBREQUESTRUNRESPONSE._serialized_end=674
  _CREATEWEBREQUESTRUNREQUEST._serialized_start=676
  _CREATEWEBREQUESTRUNREQUEST._serialized_end=796
  _UPDATEWEBREQUESTRUNREQUEST._serialized_start=799
  _UPDATEWEBREQUESTRUNREQUEST._serialized_end=967
  _UPDATEWEBREQUESTRUNRESPONSE._serialized_start=969
  _UPDATEWEBREQUESTRUNRESPONSE._serialized_end=998
  _GETWEBREQUESTRUNREQUEST._serialized_start=1000
  _GETWEBREQUESTRUNREQUEST._serialized_end=1058
  _GETWEBREQUESTRUNRESPONSE._serialized_start=1061
  _GETWEBREQUESTRUNRESPONSE._serialized_end=1193
  _DELETEWEBREQUESTRUNREQUEST._serialized_start=1195
  _DELETEWEBREQUESTRUNREQUEST._serialized_end=1256
  _DELETEWEBREQUESTRUNRESPONSE._serialized_start=1258
  _DELETEWEBREQUESTRUNRESPONSE._serialized_end=1287
  _WEBREQUESTRUNSERVICE._serialized_start=1290
  _WEBREQUESTRUNSERVICE._serialized_end=2524
# @@protoc_insertion_point(module_scope)
