# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/feature/v1/feature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/feature/v1/feature.proto\x12\x31github.com.metaprov.modelaapi.services.feature.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xf4\x01\n\x13ListFeaturesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x14ListFeaturesResponse\x12S\n\x08\x66\x65\x61tures\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"f\n\x14\x43reateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x17\n\x15\x43reateFeatureResponse\"\x96\x01\n\x14UpdateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateFeatureResponse\"4\n\x11GetFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x12GetFeatureResponse\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteFeatureResponse2\x98\x08\n\x0e\x46\x65\x61tureService\x12\xc1\x01\n\x0cListFeatures\x12\x46.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest\x1aG.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/features/{namespace}\x12\xbb\x01\n\rCreateFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/features:\x01*\x12\xc2\x01\n\nGetFeature\x12\x44.github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest\x1a\x45.github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/features/{namespace}/{name}\x12\xf0\x01\n\rUpdateFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/features/{feature.metadata.namespace}/{feature.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/features/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/feature/v1b\x06proto3')



_LISTFEATURESREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesRequest']
_LISTFEATURESREQUEST_LABELSENTRY = _LISTFEATURESREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATURESRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesResponse']
_CREATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureRequest']
_CREATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureResponse']
_UPDATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureRequest']
_UPDATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureResponse']
_GETFEATUREREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureRequest']
_GETFEATURERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureResponse']
_DELETEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureRequest']
_DELETEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureResponse']
ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATURESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)
_sym_db.RegisterMessage(ListFeaturesRequest.LabelsEntry)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)

CreateFeatureResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse)
  })
_sym_db.RegisterMessage(CreateFeatureResponse)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

GetFeatureResponse = _reflection.GeneratedProtocolMessageType('GetFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse)
  })
_sym_db.RegisterMessage(GetFeatureResponse)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

DeleteFeatureResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureResponse)

_FEATURESERVICE = DESCRIPTOR.services_by_name['FeatureService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/feature/v1'
  _LISTFEATURESREQUEST_LABELSENTRY._options = None
  _LISTFEATURESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATURESERVICE.methods_by_name['ListFeatures']._options = None
  _FEATURESERVICE.methods_by_name['ListFeatures']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/features/{namespace}'
  _FEATURESERVICE.methods_by_name['CreateFeature']._options = None
  _FEATURESERVICE.methods_by_name['CreateFeature']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/features:\001*'
  _FEATURESERVICE.methods_by_name['GetFeature']._options = None
  _FEATURESERVICE.methods_by_name['GetFeature']._serialized_options = b'\202\323\344\223\002!\022\037/v1/features/{namespace}/{name}'
  _FEATURESERVICE.methods_by_name['UpdateFeature']._options = None
  _FEATURESERVICE.methods_by_name['UpdateFeature']._serialized_options = b'\202\323\344\223\002F\032A/v1/features/{feature.metadata.namespace}/{feature.metadata.name}:\001*'
  _FEATURESERVICE.methods_by_name['DeleteFeature']._options = None
  _FEATURESERVICE.methods_by_name['DeleteFeature']._serialized_options = b'\202\323\344\223\002!*\037/v1/features/{namespace}/{name}'
  _LISTFEATURESREQUEST._serialized_start=253
  _LISTFEATURESREQUEST._serialized_end=497
  _LISTFEATURESREQUEST_LABELSENTRY._serialized_start=452
  _LISTFEATURESREQUEST_LABELSENTRY._serialized_end=497
  _LISTFEATURESRESPONSE._serialized_start=500
  _LISTFEATURESRESPONSE._serialized_end=632
  _CREATEFEATUREREQUEST._serialized_start=634
  _CREATEFEATUREREQUEST._serialized_end=736
  _CREATEFEATURERESPONSE._serialized_start=738
  _CREATEFEATURERESPONSE._serialized_end=761
  _UPDATEFEATUREREQUEST._serialized_start=764
  _UPDATEFEATUREREQUEST._serialized_end=914
  _UPDATEFEATURERESPONSE._serialized_start=916
  _UPDATEFEATURERESPONSE._serialized_end=939
  _GETFEATUREREQUEST._serialized_start=941
  _GETFEATUREREQUEST._serialized_end=993
  _GETFEATURERESPONSE._serialized_start=995
  _GETFEATURERESPONSE._serialized_end=1109
  _DELETEFEATUREREQUEST._serialized_start=1111
  _DELETEFEATUREREQUEST._serialized_end=1166
  _DELETEFEATURERESPONSE._serialized_start=1168
  _DELETEFEATURERESPONSE._serialized_end=1191
  _FEATURESERVICE._serialized_start=1194
  _FEATURESERVICE._serialized_end=2242
# @@protoc_insertion_point(module_scope)
