# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictor/v1/predictor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCgithub.com/metaprov/modelaapi/services/predictor/v1/predictor.proto\x12\x33github.com.metaprov.modelaapi.services.predictor.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xfa\x01\n\x15ListPredictorsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x16ListPredictorsResponse\x12\\\n\npredictors\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictorList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x19\n\x17\x43reatePredictorResponse\"q\n\x16\x43reatePredictorRequest\x12W\n\tpredictor\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\xa1\x01\n\x16UpdatePredictorRequest\x12W\n\tpredictor\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x19\n\x17UpdatePredictorResponse\"6\n\x13GetPredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"}\n\x14GetPredictorResponse\x12W\n\tpredictor\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16\x44\x65letePredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x44\x65letePredictorResponse\"E\n\x0fRollbackRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmodelName\x18\x03 \x01(\t\"\x12\n\x10RollbackResponse\"T\n\x11PredictOneRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ields\x18\x03 \x01(\t\x12\x0e\n\x06values\x18\x04 \x01(\t\"\xe4\x01\n\x12PredictOneResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12\x61\n\x05proba\x18\x05 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry\x1a,\n\nProbaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x32\x81\x0c\n\x10PredictorService\x12\xcd\x01\n\x0eListPredictors\x12J.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest\x1aK.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/predictors/{namespace}\x12\xc7\x01\n\x0f\x43reatePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/predictors:\x01*\x12\xce\x01\n\x0cGetPredictor\x12H.github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest\x1aI.github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/predictors/{namespace}/{name}\x12\x80\x02\n\x0fUpdatePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse\"R\x82\xd3\xe4\x93\x02L\x1aG/v1/predictors/{predictor.metadata.namespace}/{predictor.metadata.name}:\x01*\x12\xce\x01\n\x08RollBack\x12\x44.github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest\x1a\x45.github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse\"5\x82\xd3\xe4\x93\x02/\"*/v1/predictors/{namespace}/{name}:rollback:\x01*\x12\xd7\x01\n\x0f\x44\x65letePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse\")\x82\xd3\xe4\x93\x02#*!/v1/predictors/{namespace}/{name}\x12\xd3\x01\n\nPredictOne\x12\x46.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest\x1aG.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse\"4\x82\xd3\xe4\x93\x02.\",/v1/predictors/{namespace}/{name}:predictoneB5Z3github.com/metaprov/modelaapi/services/predictor/v1b\x06proto3')



_LISTPREDICTORSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictorsRequest']
_LISTPREDICTORSREQUEST_LABELSENTRY = _LISTPREDICTORSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPREDICTORSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictorsResponse']
_CREATEPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['CreatePredictorResponse']
_CREATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictorRequest']
_UPDATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictorRequest']
_UPDATEPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePredictorResponse']
_GETPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['GetPredictorRequest']
_GETPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['GetPredictorResponse']
_DELETEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictorRequest']
_DELETEPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['DeletePredictorResponse']
_ROLLBACKREQUEST = DESCRIPTOR.message_types_by_name['RollbackRequest']
_ROLLBACKRESPONSE = DESCRIPTOR.message_types_by_name['RollbackResponse']
_PREDICTONEREQUEST = DESCRIPTOR.message_types_by_name['PredictOneRequest']
_PREDICTONERESPONSE = DESCRIPTOR.message_types_by_name['PredictOneResponse']
_PREDICTONERESPONSE_PROBAENTRY = _PREDICTONERESPONSE.nested_types_by_name['ProbaEntry']
ListPredictorsRequest = _reflection.GeneratedProtocolMessageType('ListPredictorsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTORSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTORSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest)
  })
_sym_db.RegisterMessage(ListPredictorsRequest)
_sym_db.RegisterMessage(ListPredictorsRequest.LabelsEntry)

ListPredictorsResponse = _reflection.GeneratedProtocolMessageType('ListPredictorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse)
  })
_sym_db.RegisterMessage(ListPredictorsResponse)

CreatePredictorResponse = _reflection.GeneratedProtocolMessageType('CreatePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse)
  })
_sym_db.RegisterMessage(CreatePredictorResponse)

CreatePredictorRequest = _reflection.GeneratedProtocolMessageType('CreatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest)
  })
_sym_db.RegisterMessage(CreatePredictorRequest)

UpdatePredictorRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest)
  })
_sym_db.RegisterMessage(UpdatePredictorRequest)

UpdatePredictorResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse)
  })
_sym_db.RegisterMessage(UpdatePredictorResponse)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

GetPredictorResponse = _reflection.GeneratedProtocolMessageType('GetPredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse)
  })
_sym_db.RegisterMessage(GetPredictorResponse)

DeletePredictorRequest = _reflection.GeneratedProtocolMessageType('DeletePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest)
  })
_sym_db.RegisterMessage(DeletePredictorRequest)

DeletePredictorResponse = _reflection.GeneratedProtocolMessageType('DeletePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse)
  })
_sym_db.RegisterMessage(DeletePredictorResponse)

RollbackRequest = _reflection.GeneratedProtocolMessageType('RollbackRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest)
  })
_sym_db.RegisterMessage(RollbackRequest)

RollbackResponse = _reflection.GeneratedProtocolMessageType('RollbackResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse)
  })
_sym_db.RegisterMessage(RollbackResponse)

PredictOneRequest = _reflection.GeneratedProtocolMessageType('PredictOneRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTONEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest)
  })
_sym_db.RegisterMessage(PredictOneRequest)

PredictOneResponse = _reflection.GeneratedProtocolMessageType('PredictOneResponse', (_message.Message,), {

  'ProbaEntry' : _reflection.GeneratedProtocolMessageType('ProbaEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREDICTONERESPONSE_PROBAENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry)
    })
  ,
  'DESCRIPTOR' : _PREDICTONERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse)
  })
_sym_db.RegisterMessage(PredictOneResponse)
_sym_db.RegisterMessage(PredictOneResponse.ProbaEntry)

_PREDICTORSERVICE = DESCRIPTOR.services_by_name['PredictorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/metaprov/modelaapi/services/predictor/v1'
  _LISTPREDICTORSREQUEST_LABELSENTRY._options = None
  _LISTPREDICTORSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _PREDICTONERESPONSE_PROBAENTRY._options = None
  _PREDICTONERESPONSE_PROBAENTRY._serialized_options = b'8\001'
  _PREDICTORSERVICE.methods_by_name['ListPredictors']._options = None
  _PREDICTORSERVICE.methods_by_name['ListPredictors']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/predictors/{namespace}'
  _PREDICTORSERVICE.methods_by_name['CreatePredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['CreatePredictor']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/predictors:\001*'
  _PREDICTORSERVICE.methods_by_name['GetPredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['GetPredictor']._serialized_options = b'\202\323\344\223\002#\022!/v1/predictors/{namespace}/{name}'
  _PREDICTORSERVICE.methods_by_name['UpdatePredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['UpdatePredictor']._serialized_options = b'\202\323\344\223\002L\032G/v1/predictors/{predictor.metadata.namespace}/{predictor.metadata.name}:\001*'
  _PREDICTORSERVICE.methods_by_name['RollBack']._options = None
  _PREDICTORSERVICE.methods_by_name['RollBack']._serialized_options = b'\202\323\344\223\002/\"*/v1/predictors/{namespace}/{name}:rollback:\001*'
  _PREDICTORSERVICE.methods_by_name['DeletePredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['DeletePredictor']._serialized_options = b'\202\323\344\223\002#*!/v1/predictors/{namespace}/{name}'
  _PREDICTORSERVICE.methods_by_name['PredictOne']._options = None
  _PREDICTORSERVICE.methods_by_name['PredictOne']._serialized_options = b'\202\323\344\223\002.\",/v1/predictors/{namespace}/{name}:predictone'
  _LISTPREDICTORSREQUEST._serialized_start=264
  _LISTPREDICTORSREQUEST._serialized_end=514
  _LISTPREDICTORSREQUEST_LABELSENTRY._serialized_start=469
  _LISTPREDICTORSREQUEST_LABELSENTRY._serialized_end=514
  _LISTPREDICTORSRESPONSE._serialized_start=517
  _LISTPREDICTORSRESPONSE._serialized_end=660
  _CREATEPREDICTORRESPONSE._serialized_start=662
  _CREATEPREDICTORRESPONSE._serialized_end=687
  _CREATEPREDICTORREQUEST._serialized_start=689
  _CREATEPREDICTORREQUEST._serialized_end=802
  _UPDATEPREDICTORREQUEST._serialized_start=805
  _UPDATEPREDICTORREQUEST._serialized_end=966
  _UPDATEPREDICTORRESPONSE._serialized_start=968
  _UPDATEPREDICTORRESPONSE._serialized_end=993
  _GETPREDICTORREQUEST._serialized_start=995
  _GETPREDICTORREQUEST._serialized_end=1049
  _GETPREDICTORRESPONSE._serialized_start=1051
  _GETPREDICTORRESPONSE._serialized_end=1176
  _DELETEPREDICTORREQUEST._serialized_start=1178
  _DELETEPREDICTORREQUEST._serialized_end=1235
  _DELETEPREDICTORRESPONSE._serialized_start=1237
  _DELETEPREDICTORRESPONSE._serialized_end=1262
  _ROLLBACKREQUEST._serialized_start=1264
  _ROLLBACKREQUEST._serialized_end=1333
  _ROLLBACKRESPONSE._serialized_start=1335
  _ROLLBACKRESPONSE._serialized_end=1353
  _PREDICTONEREQUEST._serialized_start=1355
  _PREDICTONEREQUEST._serialized_end=1439
  _PREDICTONERESPONSE._serialized_start=1442
  _PREDICTONERESPONSE._serialized_end=1670
  _PREDICTONERESPONSE_PROBAENTRY._serialized_start=1626
  _PREDICTONERESPONSE_PROBAENTRY._serialized_end=1670
  _PREDICTORSERVICE._serialized_start=1673
  _PREDICTORSERVICE._serialized_end=3210
# @@protoc_insertion_point(module_scope)
