# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto\x12\x32github.com.metaprov.modelaapi.services.dbproxyd.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1bgoogle/protobuf/empty.proto\"O\n\x13ListAccountsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x14ListAccountsResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x14\x43reateAccountRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"d\n\x14UpdateAccountRequest\x12L\n\x04item\x18\x02 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"7\n\x14\x44\x65leteAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x11ListAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"z\n\x12ListAlertsResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x12\x43reateAlertRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"`\n\x12UpdateAlertRequest\x12J\n\x04item\x18\x02 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"5\n\x12\x44\x65leteAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListAttachmentsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x84\x01\n\x17ListAttachmentsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"j\n\x17\x43reateAttachmentRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"j\n\x17UpdateAttachmentRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\":\n\x17\x44\x65leteAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x10ListTodosRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n\x11ListTodosResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"1\n\x0eGetTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"]\n\x11\x43reateTodoRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"]\n\x11UpdateTodoRequest\x12H\n\x04item\x18\x02 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"4\n\x11\x44\x65leteTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListMeetingsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListMeetingsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetMeetingRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateMeetingRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"c\n\x14UpdateMeetingRequest\x12K\n\x04item\x18\x02 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"7\n\x14\x44\x65leteMeetingRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListCommitsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x13ListCommitsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetCommitRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x13\x43reateCommitRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"b\n\x13UpdateCommitRequest\x12K\n\x04item\x18\x02 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"6\n\x13\x44\x65leteCommitRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListApiTokensRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x80\x01\n\x15ListApiTokensResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x15\x43reateApiTokenRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"f\n\x15UpdateApiTokenRequest\x12M\n\x04item\x18\x02 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"8\n\x15\x44\x65leteApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListConnectionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x84\x01\n\x17ListConnectionsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"j\n\x17\x43reateConnectionRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"j\n\x17UpdateConnectionRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\":\n\x17\x44\x65leteConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0fListLabsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n\x10ListLabsResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"0\n\rGetLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\\\n\x10\x43reateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\\\n\x10UpdateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"3\n\x10\x44\x65leteLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListLicensesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x14ListLicensesResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x14\x43reateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"d\n\x14UpdateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"7\n\x14\x44\x65leteLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListNotifiersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x80\x01\n\x15ListNotifiersResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x15\x43reateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"f\n\x15UpdateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"8\n\x15\x44\x65leteNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListServingsitesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x18ListServingsitesResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetServingsiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x18\x43reateServingsiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"l\n\x18UpdateServingsiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\";\n\x18\x44\x65leteServingsiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListTenantsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x13ListTenantsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x13\x43reateTenantRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"b\n\x13UpdateTenantRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"6\n\x13\x44\x65leteTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListVirtualBucketsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8a\x01\n\x1aListVirtualBucketsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x1a\x43reateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"p\n\x1aUpdateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"=\n\x1a\x44\x65leteVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1aListVirtualClustersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8c\x01\n\x1bListVirtualClustersResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x18GetVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x1b\x43reateVirtualClusterRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"r\n\x1bUpdateVirtualClusterRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\">\n\x1b\x44\x65leteVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListVirtualVolumesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8a\x01\n\x1aListVirtualVolumesResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x1a\x43reateVirtualVolumeRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"p\n\x1aUpdateVirtualVolumeRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"=\n\x1a\x44\x65leteVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"T\n\x18ListDataPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x87\x01\n\x19ListDataPipelinesResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x16GetDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x19\x43reateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"m\n\x19UpdateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"<\n\x19\x44\x65leteDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\x1bListDataPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1cListDataPipelineRunsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1c\x43reateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"s\n\x1cUpdateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListDataProductsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x85\x01\n\x18ListDataProductsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n\x18\x43reateDataProductRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"k\n\x18UpdateDataProductRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\";\n\x18\x44\x65leteDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Z\n\x1eListDataProductVersionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1fListDataProductVersionsResponse\x12W\n\x05items\x18\x01 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x1cGetDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1f\x43reateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"y\n\x1fUpdateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"B\n\x1f\x44\x65leteDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListDatasetsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"c\n\x14UpdateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"7\n\x14\x44\x65leteDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListDatasourcesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListDatasourcesResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetDatasourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reateDatasourceRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"i\n\x17UpdateDatasourceRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\":\n\x17\x44\x65leteDatasourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListEntitiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x14ListEntitiesResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateEntityRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"a\n\x13UpdateEntityRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"6\n\x13\x44\x65leteEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListFeaturesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListFeaturesResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"c\n\x14UpdateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"7\n\x14\x44\x65leteFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListFeatureHistogramsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8f\x01\n\x1dListFeatureHistogramsResponse\x12U\n\x05items\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x1d\x43reateFeatureHistogramRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"u\n\x1dUpdateFeatureHistogramRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"@\n\x1d\x44\x65leteFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\x1bListFeaturePipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1cListFeaturePipelinesResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"<\n\x19GetFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1c\x43reateFeaturePipelineRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"s\n\x1cUpdateFeaturePipelineRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"?\n\x1c\x44\x65leteFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Z\n\x1eListFeaturePipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1fListFeaturePipelineRunsResponse\x12W\n\x05items\x18\x01 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x1cGetFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1f\x43reateFeaturePipelineRunRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"y\n\x1fUpdateFeaturePipelineRunRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"B\n\x1f\x44\x65leteFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListFeaturesetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListFeaturesetsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reateFeaturesetRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"i\n\x17UpdateFeaturesetRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\":\n\x17\x44\x65leteFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListLabelingPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8f\x01\n\x1dListLabelingPipelinesResponse\x12U\n\x05items\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x1d\x43reateLabelingPipelineRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"u\n\x1dUpdateLabelingPipelineRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"@\n\x1d\x44\x65leteLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"[\n\x1fListLabelingPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x95\x01\n ListLabelingPipelineRunsResponse\x12X\n\x05items\x18\x01 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"@\n\x1dGetLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n CreateLabelingPipelineRunRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"{\n UpdateLabelingPipelineRunRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"C\n DeleteLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListRecipesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x13ListRecipesResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"a\n\x13UpdateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"6\n\x13\x44\x65leteRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Q\n\x15ListRecipeRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x81\x01\n\x16ListRecipeRunsResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x13GetRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x16\x43reateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"g\n\x16UpdateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"9\n\x16\x44\x65leteRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListModelAutobuildersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1dListModelAutobuildersResponse\x12Y\n\x05items\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1d\x43reateModelAutobuilderRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"y\n\x1dUpdateModelAutobuilderRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"@\n\x1d\x44\x65leteModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x11ListModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x12ListModelsResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"c\n\x12UpdateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"5\n\x12\x44\x65leteModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListModelPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1aListModelPipelinesResponse\x12V\n\x05items\x18\x01 \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1a\x43reateModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"s\n\x1aUpdateModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"=\n\x1a\x44\x65leteModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListModelPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1dListModelPipelineRunsResponse\x12Y\n\x05items\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1d\x43reateModelPipelineRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"y\n\x1dUpdateModelPipelineRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"@\n\x1d\x44\x65leteModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListNotebooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x15ListNotebooksResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x15\x43reateNotebookRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"i\n\x15UpdateNotebookRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"8\n\x15\x44\x65leteNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListNotebookRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x89\x01\n\x18ListNotebookRunsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x18\x43reateNotebookRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"o\n\x18UpdateNotebookRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\";\n\x18\x44\x65leteNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x7f\n\x13ListReportsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"e\n\x13\x43reateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"e\n\x13UpdateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"6\n\x13\x44\x65leteReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListCronReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x87\x01\n\x17ListCronReportsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x17\x43reateCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"m\n\x17UpdateCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\":\n\x17\x44\x65leteCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListStudiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x13ListStudiesResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"c\n\x12UpdateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"5\n\x12\x44\x65leteStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1aListCronPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x90\x01\n\x1bListCronPredictionsResponse\x12X\n\x05items\x18\x01 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x18GetCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x1b\x43reateCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"v\n\x1bUpdateCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\">\n\x1b\x44\x65leteCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListCurtainsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x82\x01\n\x14ListCurtainsResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x14\x43reateCurtainRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"h\n\x14UpdateCurtainRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"7\n\x14\x44\x65leteCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n\x17ListPredictionsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"n\n\x17\x43reatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"n\n\x17UpdatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\":\n\x17\x44\x65letePredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Q\n\x15ListPredictorsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x16ListPredictorsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x13GetPredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x16\x43reatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"l\n\x16UpdatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"9\n\x16\x44\x65letePredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListReviewsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x13ListReviewsResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateReviewRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"a\n\x13UpdateReviewRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"6\n\x13\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListPostMortemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListPostMortemsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetPostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"i\n\x17UpdatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\":\n\x17\x44\x65letePostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListRunbooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListRunbooksResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetRunbookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateRunbookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"c\n\x14UpdateRunbookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"7\n\x14\x44\x65leteRunbookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListSqlQuerysRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x7f\n\x15ListSqlQuerysResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetSqlQueryRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"e\n\x15\x43reateSqlQueryRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"e\n\x15UpdateSqlQueryRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"8\n\x15\x44\x65leteSqlQueryRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListSqlQueryRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x85\x01\n\x18ListSqlQueryRunsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n\x18\x43reateSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"k\n\x18UpdateSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\";\n\x18\x44\x65leteSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListWebRequestsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListWebRequestsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reateWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"i\n\x17UpdateWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\":\n\x17\x44\x65leteWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListWebRequestRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x89\x01\n\x1aListWebRequestRunsResponse\x12R\n\x05items\x18\x01 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x1a\x43reateWebRequestRunRequest\x12Q\n\x04item\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"o\n\x1aUpdateWebRequestRunRequest\x12Q\n\x04item\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"=\n\x1a\x44\x65leteWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x81\x01\n\x13ListDataAppResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x14\x43reateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"h\n\x14UpdateDataAppRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"7\n\x14\x44\x65leteDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\x85\xc9\x02\n\x14\x44\x61tabaseProxyService\x12\xa3\x01\n\x0cListAccounts\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse\"\x00\x12\x95\x01\n\nGetAccount\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12\x9b\x01\n\rCreateAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12\x9b\x01\n\rUpdateAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12s\n\rDeleteAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9d\x01\n\nListAlerts\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest\x1a\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse\"\x00\x12\x8f\x01\n\x08GetAlert\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12\x95\x01\n\x0b\x43reateAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12\x95\x01\n\x0bUpdateAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12o\n\x0b\x44\x65leteAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9a\x01\n\tListTodos\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest\x1a\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse\"\x00\x12\x8b\x01\n\x07GetTodo\x12\x42.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12\x91\x01\n\nCreateTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12\x91\x01\n\nUpdateTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12m\n\nDeleteTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListMeetings\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListMeetingsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListMeetingsResponse\"\x00\x12\x94\x01\n\nGetMeeting\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetMeetingRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"\x00\x12\x9a\x01\n\rCreateMeeting\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateMeetingRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"\x00\x12\x9a\x01\n\rUpdateMeeting\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateMeetingRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\"\x00\x12s\n\rDeleteMeeting\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteMeetingRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListAttachments\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsResponse\"\x00\x12\x9e\x01\n\rGetAttachment\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAttachmentRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x00\x12\xa4\x01\n\x10\x43reateAttachment\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAttachmentRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x00\x12\xa4\x01\n\x10UpdateAttachment\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAttachmentRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x00\x12y\n\x10\x44\x65leteAttachment\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAttachmentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListCommits\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse\"\x00\x12\x92\x01\n\tGetCommit\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"\x00\x12\x98\x01\n\x0c\x43reateCommit\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCommitRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"\x00\x12\x98\x01\n\x0cUpdateCommit\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCommitRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"\x00\x12q\n\x0c\x44\x65leteCommit\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListApiTokens\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse\"\x00\x12\x98\x01\n\x0bGetApiToken\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x00\x12\x9e\x01\n\x0e\x43reateApiToken\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateApiTokenRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x00\x12\x9e\x01\n\x0eUpdateApiToken\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateApiTokenRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x00\x12u\n\x0e\x44\x65leteApiToken\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListConnections\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse\"\x00\x12\x9e\x01\n\rGetConnection\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12\xa4\x01\n\x10\x43reateConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12\xa4\x01\n\x10UpdateConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12y\n\x10\x44\x65leteConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x97\x01\n\x08ListLabs\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest\x1a\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse\"\x00\x12\x89\x01\n\x06GetLab\x12\x41.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12\x8f\x01\n\tCreateLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12\x8f\x01\n\tUpdateLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12k\n\tDeleteLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListLicenses\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse\"\x00\x12\x95\x01\n\nGetLicense\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12\x9b\x01\n\rCreateLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12\x9b\x01\n\rUpdateLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12s\n\rDeleteLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListNotifiers\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse\"\x00\x12\x98\x01\n\x0bGetNotifier\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12\x9e\x01\n\x0e\x43reateNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12\x9e\x01\n\x0eUpdateNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12u\n\x0e\x44\x65leteNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListServingSites\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse\"\x00\x12\xa1\x01\n\x0eGetServingSite\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12\xa7\x01\n\x11\x43reateServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12\xa7\x01\n\x11UpdateServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12{\n\x11\x44\x65leteServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListTenants\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse\"\x00\x12\x92\x01\n\tGetTenant\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12\x98\x01\n\x0c\x43reateTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12\x98\x01\n\x0cUpdateTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12q\n\x0c\x44\x65leteTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListVirtualBuckets\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse\"\x00\x12\xa7\x01\n\x10GetVirtualBucket\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\xad\x01\n\x13\x43reateVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\xad\x01\n\x13UpdateVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\x7f\n\x13\x44\x65leteVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb8\x01\n\x13ListVirtualClusters\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest\x1aO.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse\"\x00\x12\xaa\x01\n\x11GetVirtualCluster\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x00\x12\xb0\x01\n\x14\x43reateVirtualCluster\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualClusterRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x00\x12\xb0\x01\n\x14UpdateVirtualCluster\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualClusterRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x00\x12\x81\x01\n\x14\x44\x65leteVirtualCluster\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListVirtualVolumes\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse\"\x00\x12\xa7\x01\n\x10GetVirtualVolume\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x00\x12\xad\x01\n\x13\x43reateVirtualVolume\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualVolumeRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x00\x12\xad\x01\n\x13UpdateVirtualVolume\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualVolumeRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x00\x12\x7f\n\x13\x44\x65leteVirtualVolume\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb2\x01\n\x11ListDataPipelines\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest\x1aM.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse\"\x00\x12\xa3\x01\n\x0fGetDataPipeline\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12\xa9\x01\n\x12\x43reateDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12\xa9\x01\n\x12UpdateDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12}\n\x12\x44\x65leteDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbb\x01\n\x14ListDataPipelineRuns\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest\x1aP.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse\"\x00\x12\xac\x01\n\x12GetDataPipelineRun\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\xb2\x01\n\x15\x43reateDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\xb2\x01\n\x15UpdateDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\x83\x01\n\x15\x44\x65leteDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListDataProducts\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse\"\x00\x12\xa0\x01\n\x0eGetDataProduct\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12\xa6\x01\n\x11\x43reateDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12\xa6\x01\n\x11UpdateDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12{\n\x11\x44\x65leteDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc4\x01\n\x17ListDataProductVersions\x12R.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest\x1aS.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse\"\x00\x12\xb5\x01\n\x15GetDataProductVersion\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\xbb\x01\n\x18\x43reateDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\xbb\x01\n\x18UpdateDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\x89\x01\n\x18\x44\x65leteDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListDatasets\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse\"\x00\x12\x94\x01\n\nGetDataset\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12\x9a\x01\n\rCreateDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12\x9a\x01\n\rUpdateDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12s\n\rDeleteDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListDataSources\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse\"\x00\x12\x9d\x01\n\rGetDataSource\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12\xa3\x01\n\x10\x43reateDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12\xa3\x01\n\x10UpdateDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12y\n\x10\x44\x65leteDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListEntities\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse\"\x00\x12\x91\x01\n\tGetEntity\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12\x97\x01\n\x0c\x43reateEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12\x97\x01\n\x0cUpdateEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12q\n\x0c\x44\x65leteEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListFeatures\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse\"\x00\x12\x94\x01\n\nGetFeature\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x00\x12\x9a\x01\n\rCreateFeature\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x00\x12\x9a\x01\n\rUpdateFeature\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x00\x12s\n\rDeleteFeature\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListFeatureHistograms\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsResponse\"\x00\x12\xaf\x01\n\x13GetFeatureHistogram\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureHistogramRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x00\x12\xb5\x01\n\x16\x43reateFeatureHistogram\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureHistogramRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x00\x12\xb5\x01\n\x16UpdateFeatureHistogram\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureHistogramRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\x00\x12\x85\x01\n\x16\x44\x65leteFeatureHistogram\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureHistogramRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbb\x01\n\x14ListFeaturePipelines\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest\x1aP.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse\"\x00\x12\xac\x01\n\x12GetFeaturePipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x00\x12\xb2\x01\n\x15\x43reateFeaturePipeline\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x00\x12\xb2\x01\n\x15UpdateFeaturePipeline\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x00\x12\x83\x01\n\x15\x44\x65leteFeaturePipeline\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc4\x01\n\x17ListFeaturePipelineRuns\x12R.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest\x1aS.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse\"\x00\x12\xb5\x01\n\x15GetFeaturePipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\x00\x12\xbb\x01\n\x18\x43reateFeaturePipelineRun\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRunRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\x00\x12\xbb\x01\n\x18UpdateFeaturePipelineRun\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRunRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\x00\x12\x89\x01\n\x18\x44\x65leteFeaturePipelineRun\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListFeaturesets\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse\"\x00\x12\x9d\x01\n\rGetFeatureset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x00\x12\xa3\x01\n\x10\x43reateFeatureset\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturesetRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x00\x12\xa3\x01\n\x10UpdateFeatureset\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturesetRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x00\x12y\n\x10\x44\x65leteFeatureset\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListLabelingPipelines\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse\"\x00\x12\xaf\x01\n\x13GetLabelingPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x00\x12\xb5\x01\n\x16\x43reateLabelingPipeline\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x00\x12\xb5\x01\n\x16UpdateLabelingPipeline\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x00\x12\x85\x01\n\x16\x44\x65leteLabelingPipeline\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc7\x01\n\x18ListLabelingPipelineRuns\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest\x1aT.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse\"\x00\x12\xb8\x01\n\x16GetLabelingPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\x00\x12\xbe\x01\n\x19\x43reateLabelingPipelineRun\x12T.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRunRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\x00\x12\xbe\x01\n\x19UpdateLabelingPipelineRun\x12T.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRunRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\x00\x12\x8b\x01\n\x19\x44\x65leteLabelingPipelineRun\x12T.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListRecipes\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse\"\x00\x12\x91\x01\n\tGetRecipe\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12\x97\x01\n\x0c\x43reateRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12\x97\x01\n\x0cUpdateRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12q\n\x0c\x44\x65leteRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa9\x01\n\x0eListRecipeRuns\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest\x1aJ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse\"\x00\x12\x9a\x01\n\x0cGetRecipeRun\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12\xa0\x01\n\x0f\x43reateRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12\xa0\x01\n\x0fUpdateRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12w\n\x0f\x44\x65leteRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListModelAutobuilders\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse\"\x00\x12\xb3\x01\n\x13GetModelAutobuilder\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\x00\x12\xb9\x01\n\x16\x43reateModelAutobuilder\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelAutobuilderRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\x00\x12\xb9\x01\n\x16UpdateModelAutobuilder\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelAutobuilderRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\x00\x12\x85\x01\n\x16\x44\x65leteModelAutobuilder\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListModelPipelines\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse\"\x00\x12\xaa\x01\n\x10GetModelPipeline\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x00\x12\xb0\x01\n\x13\x43reateModelPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x00\x12\xb0\x01\n\x13UpdateModelPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x00\x12\x7f\n\x13\x44\x65leteModelPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListModelPipelineRuns\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse\"\x00\x12\xb3\x01\n\x13GetModelPipelineRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\x00\x12\xb9\x01\n\x16\x43reateModelPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRunRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\x00\x12\xb9\x01\n\x16UpdateModelPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRunRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\x00\x12\x85\x01\n\x16\x44\x65leteModelPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListNotebooks\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse\"\x00\x12\x9b\x01\n\x0bGetNotebook\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x00\x12\xa1\x01\n\x0e\x43reateNotebook\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x00\x12\xa1\x01\n\x0eUpdateNotebook\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x00\x12u\n\x0e\x44\x65leteNotebook\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListNotebookRuns\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse\"\x00\x12\xa4\x01\n\x0eGetNotebookRun\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x00\x12\xaa\x01\n\x11\x43reateNotebookRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x00\x12\xaa\x01\n\x11UpdateNotebookRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x00\x12{\n\x11\x44\x65leteNotebookRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListReports\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse\"\x00\x12\x95\x01\n\tGetReport\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12\x9b\x01\n\x0c\x43reateReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12\x9b\x01\n\x0cUpdateReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12q\n\x0c\x44\x65leteReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListCronReports\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse\"\x00\x12\xa1\x01\n\rGetCronReport\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x00\x12\xa7\x01\n\x10\x43reateCronReport\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronReportRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x00\x12\xa7\x01\n\x10UpdateCronReport\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronReportRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x00\x12y\n\x10\x44\x65leteCronReport\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListStudies\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse\"\x00\x12\x92\x01\n\x08GetStudy\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12\x98\x01\n\x0b\x43reateStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12\x98\x01\n\x0bUpdateStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12o\n\x0b\x44\x65leteStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9d\x01\n\nListModels\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest\x1a\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse\"\x00\x12\x92\x01\n\x08GetModel\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12\x98\x01\n\x0b\x43reateModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12\x98\x01\n\x0bUpdateModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12o\n\x0b\x44\x65leteModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb8\x01\n\x13ListCronPredictions\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest\x1aO.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse\"\x00\x12\xae\x01\n\x11GetCronPrediction\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x00\x12\xb4\x01\n\x14\x43reateCronPrediction\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronPredictionRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x00\x12\xb4\x01\n\x14UpdateCronPrediction\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronPredictionRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x00\x12\x81\x01\n\x14\x44\x65leteCronPrediction\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListPredictions\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse\"\x00\x12\xa2\x01\n\rGetPrediction\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12\xa8\x01\n\x10\x43reatePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12\xa8\x01\n\x10UpdatePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12y\n\x10\x44\x65letePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa9\x01\n\x0eListPredictors\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest\x1aJ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse\"\x00\x12\x9f\x01\n\x0cGetPredictor\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12\xa5\x01\n\x0f\x43reatePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12\xa5\x01\n\x0fUpdatePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12w\n\x0f\x44\x65letePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListCurtains\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse\"\x00\x12\x99\x01\n\nGetCurtain\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x00\x12\x9f\x01\n\rCreateCurtain\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCurtainRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x00\x12\x9f\x01\n\rUpdateCurtain\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCurtainRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x00\x12s\n\rDeleteCurtain\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListReviews\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse\"\x00\x12\x91\x01\n\tGetReview\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12\x97\x01\n\x0c\x43reateReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12\x97\x01\n\x0cUpdateReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12q\n\x0c\x44\x65leteReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListPostMortems\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse\"\x00\x12\x9d\x01\n\rGetPostMortem\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12\xa3\x01\n\x10\x43reatePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12\xa3\x01\n\x10UpdatePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12y\n\x10\x44\x65letePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListRunBooks\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse\"\x00\x12\x94\x01\n\nGetRunBook\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12\x9a\x01\n\rCreateRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12\x9a\x01\n\rUpdateRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12s\n\rDeleteRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa7\x01\n\x0eListSqlQueries\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQuerysRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQuerysResponse\"\x00\x12\x97\x01\n\x0bGetSqlQuery\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetSqlQueryRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x00\x12\x9d\x01\n\x0e\x43reateSqlQuery\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateSqlQueryRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x00\x12\x9d\x01\n\x0eUpdateSqlQuery\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateSqlQueryRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x00\x12u\n\x0e\x44\x65leteSqlQuery\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteSqlQueryRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListSqlQueryRuns\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQueryRunsRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQueryRunsResponse\"\x00\x12\xa0\x01\n\x0eGetSqlQueryRun\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetSqlQueryRunRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x00\x12\xa6\x01\n\x11\x43reateSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateSqlQueryRunRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x00\x12\xa6\x01\n\x11UpdateSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateSqlQueryRunRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x00\x12{\n\x11\x44\x65leteSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteSqlQueryRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb4\x01\n\x11ListWebRequestRun\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestRunsRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestRunsResponse\"\x00\x12\xa6\x01\n\x10GetWebRequestRun\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetWebRequestRunRequest\x1a\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\x00\x12\xac\x01\n\x13\x43reateWebRequestRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateWebRequestRunRequest\x1a\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\x00\x12\xac\x01\n\x13UpdateWebRequestRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateWebRequestRunRequest\x1a\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\x00\x12\x7f\n\x13\x44\x65leteWebRequestRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteWebRequestRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListWebRequests\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestsResponse\"\x00\x12\x9d\x01\n\rGetWebRequest\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetWebRequestRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x00\x12\xa3\x01\n\x10\x43reateWebRequest\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateWebRequestRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x00\x12\xa3\x01\n\x10UpdateWebRequest\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateWebRequestRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x00\x12y\n\x10\x44\x65leteWebRequest\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteWebRequestRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListDataApp\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppResponse\"\x00\x12\x99\x01\n\nGetDataApp\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataAppRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x00\x12\x9f\x01\n\rCreateDataApp\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataAppRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x00\x12\x9f\x01\n\rUpdateDataApp\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataAppRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x00\x12s\n\rDeleteDataApp\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataAppRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x34Z2github.com/metaprov/modelaapi/services/dbproxyd/v1b\x06proto3')



_LISTACCOUNTSREQUEST = DESCRIPTOR.message_types_by_name['ListAccountsRequest']
_LISTACCOUNTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAccountsResponse']
_GETACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetAccountRequest']
_CREATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountRequest']
_UPDATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAccountRequest']
_DELETEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAccountRequest']
_LISTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListAlertsRequest']
_LISTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertsResponse']
_GETALERTREQUEST = DESCRIPTOR.message_types_by_name['GetAlertRequest']
_CREATEALERTREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertRequest']
_UPDATEALERTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertRequest']
_DELETEALERTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAlertRequest']
_LISTATTACHMENTSREQUEST = DESCRIPTOR.message_types_by_name['ListAttachmentsRequest']
_LISTATTACHMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAttachmentsResponse']
_GETATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['GetAttachmentRequest']
_CREATEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['CreateAttachmentRequest']
_UPDATEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAttachmentRequest']
_DELETEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAttachmentRequest']
_LISTTODOSREQUEST = DESCRIPTOR.message_types_by_name['ListTodosRequest']
_LISTTODOSRESPONSE = DESCRIPTOR.message_types_by_name['ListTodosResponse']
_GETTODOREQUEST = DESCRIPTOR.message_types_by_name['GetTodoRequest']
_CREATETODOREQUEST = DESCRIPTOR.message_types_by_name['CreateTodoRequest']
_UPDATETODOREQUEST = DESCRIPTOR.message_types_by_name['UpdateTodoRequest']
_DELETETODOREQUEST = DESCRIPTOR.message_types_by_name['DeleteTodoRequest']
_LISTMEETINGSREQUEST = DESCRIPTOR.message_types_by_name['ListMeetingsRequest']
_LISTMEETINGSRESPONSE = DESCRIPTOR.message_types_by_name['ListMeetingsResponse']
_GETMEETINGREQUEST = DESCRIPTOR.message_types_by_name['GetMeetingRequest']
_CREATEMEETINGREQUEST = DESCRIPTOR.message_types_by_name['CreateMeetingRequest']
_UPDATEMEETINGREQUEST = DESCRIPTOR.message_types_by_name['UpdateMeetingRequest']
_DELETEMEETINGREQUEST = DESCRIPTOR.message_types_by_name['DeleteMeetingRequest']
_LISTCOMMITSREQUEST = DESCRIPTOR.message_types_by_name['ListCommitsRequest']
_LISTCOMMITSRESPONSE = DESCRIPTOR.message_types_by_name['ListCommitsResponse']
_GETCOMMITREQUEST = DESCRIPTOR.message_types_by_name['GetCommitRequest']
_CREATECOMMITREQUEST = DESCRIPTOR.message_types_by_name['CreateCommitRequest']
_UPDATECOMMITREQUEST = DESCRIPTOR.message_types_by_name['UpdateCommitRequest']
_DELETECOMMITREQUEST = DESCRIPTOR.message_types_by_name['DeleteCommitRequest']
_LISTAPITOKENSREQUEST = DESCRIPTOR.message_types_by_name['ListApiTokensRequest']
_LISTAPITOKENSRESPONSE = DESCRIPTOR.message_types_by_name['ListApiTokensResponse']
_GETAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['GetApiTokenRequest']
_CREATEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['CreateApiTokenRequest']
_UPDATEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['UpdateApiTokenRequest']
_DELETEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['DeleteApiTokenRequest']
_LISTCONNECTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListConnectionsRequest']
_LISTCONNECTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListConnectionsResponse']
_GETCONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['GetConnectionRequest']
_CREATECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['CreateConnectionRequest']
_UPDATECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateConnectionRequest']
_DELETECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteConnectionRequest']
_LISTLABSREQUEST = DESCRIPTOR.message_types_by_name['ListLabsRequest']
_LISTLABSRESPONSE = DESCRIPTOR.message_types_by_name['ListLabsResponse']
_GETLABREQUEST = DESCRIPTOR.message_types_by_name['GetLabRequest']
_CREATELABREQUEST = DESCRIPTOR.message_types_by_name['CreateLabRequest']
_UPDATELABREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabRequest']
_DELETELABREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabRequest']
_LISTLICENSESREQUEST = DESCRIPTOR.message_types_by_name['ListLicensesRequest']
_LISTLICENSESRESPONSE = DESCRIPTOR.message_types_by_name['ListLicensesResponse']
_GETLICENSEREQUEST = DESCRIPTOR.message_types_by_name['GetLicenseRequest']
_CREATELICENSEREQUEST = DESCRIPTOR.message_types_by_name['CreateLicenseRequest']
_UPDATELICENSEREQUEST = DESCRIPTOR.message_types_by_name['UpdateLicenseRequest']
_DELETELICENSEREQUEST = DESCRIPTOR.message_types_by_name['DeleteLicenseRequest']
_LISTNOTIFIERSREQUEST = DESCRIPTOR.message_types_by_name['ListNotifiersRequest']
_LISTNOTIFIERSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotifiersResponse']
_GETNOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['GetNotifierRequest']
_CREATENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['CreateNotifierRequest']
_UPDATENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotifierRequest']
_DELETENOTIFIERREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotifierRequest']
_LISTSERVINGSITESREQUEST = DESCRIPTOR.message_types_by_name['ListServingsitesRequest']
_LISTSERVINGSITESRESPONSE = DESCRIPTOR.message_types_by_name['ListServingsitesResponse']
_GETSERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['GetServingsiteRequest']
_CREATESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['CreateServingsiteRequest']
_UPDATESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['UpdateServingsiteRequest']
_DELETESERVINGSITEREQUEST = DESCRIPTOR.message_types_by_name['DeleteServingsiteRequest']
_LISTTENANTSREQUEST = DESCRIPTOR.message_types_by_name['ListTenantsRequest']
_LISTTENANTSRESPONSE = DESCRIPTOR.message_types_by_name['ListTenantsResponse']
_GETTENANTREQUEST = DESCRIPTOR.message_types_by_name['GetTenantRequest']
_CREATETENANTREQUEST = DESCRIPTOR.message_types_by_name['CreateTenantRequest']
_UPDATETENANTREQUEST = DESCRIPTOR.message_types_by_name['UpdateTenantRequest']
_DELETETENANTREQUEST = DESCRIPTOR.message_types_by_name['DeleteTenantRequest']
_LISTVIRTUALBUCKETSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualBucketsRequest']
_LISTVIRTUALBUCKETSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualBucketsResponse']
_GETVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualBucketRequest']
_CREATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest']
_UPDATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualBucketRequest']
_DELETEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualBucketRequest']
_LISTVIRTUALCLUSTERSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualClustersRequest']
_LISTVIRTUALCLUSTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualClustersResponse']
_GETVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualClusterRequest']
_CREATEVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualClusterRequest']
_UPDATEVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualClusterRequest']
_DELETEVIRTUALCLUSTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualClusterRequest']
_LISTVIRTUALVOLUMESREQUEST = DESCRIPTOR.message_types_by_name['ListVirtualVolumesRequest']
_LISTVIRTUALVOLUMESRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtualVolumesResponse']
_GETVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['GetVirtualVolumeRequest']
_CREATEVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualVolumeRequest']
_UPDATEVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtualVolumeRequest']
_DELETEVIRTUALVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtualVolumeRequest']
_LISTDATAPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelinesRequest']
_LISTDATAPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelinesResponse']
_GETDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRequest']
_CREATEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRequest']
_UPDATEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRequest']
_DELETEDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRequest']
_LISTDATAPIPELINERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListDataPipelineRunsRequest']
_LISTDATAPIPELINERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataPipelineRunsResponse']
_GETDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest']
_CREATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest']
_UPDATEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest']
_DELETEDATAPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest']
_LISTDATAPRODUCTSREQUEST = DESCRIPTOR.message_types_by_name['ListDataProductsRequest']
_LISTDATAPRODUCTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataProductsResponse']
_GETDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['GetDataProductRequest']
_CREATEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['CreateDataProductRequest']
_UPDATEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataProductRequest']
_DELETEDATAPRODUCTREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataProductRequest']
_LISTDATAPRODUCTVERSIONSREQUEST = DESCRIPTOR.message_types_by_name['ListDataProductVersionsRequest']
_LISTDATAPRODUCTVERSIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataProductVersionsResponse']
_GETDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetDataProductVersionRequest']
_CREATEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['CreateDataProductVersionRequest']
_UPDATEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataProductVersionRequest']
_DELETEDATAPRODUCTVERSIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataProductVersionRequest']
_LISTDATASETSREQUEST = DESCRIPTOR.message_types_by_name['ListDatasetsRequest']
_LISTDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['ListDatasetsResponse']
_GETDATASETREQUEST = DESCRIPTOR.message_types_by_name['GetDatasetRequest']
_CREATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasetRequest']
_UPDATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['UpdateDatasetRequest']
_DELETEDATASETREQUEST = DESCRIPTOR.message_types_by_name['DeleteDatasetRequest']
_LISTDATASOURCESREQUEST = DESCRIPTOR.message_types_by_name['ListDatasourcesRequest']
_LISTDATASOURCESRESPONSE = DESCRIPTOR.message_types_by_name['ListDatasourcesResponse']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDatasourceRequest']
_CREATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasourceRequest']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDatasourceRequest']
_DELETEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDatasourceRequest']
_LISTENTITIESREQUEST = DESCRIPTOR.message_types_by_name['ListEntitiesRequest']
_LISTENTITIESRESPONSE = DESCRIPTOR.message_types_by_name['ListEntitiesResponse']
_GETENTITYREQUEST = DESCRIPTOR.message_types_by_name['GetEntityRequest']
_CREATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['CreateEntityRequest']
_UPDATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEntityRequest']
_DELETEENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeleteEntityRequest']
_LISTFEATURESREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesRequest']
_LISTFEATURESRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesResponse']
_GETFEATUREREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureRequest']
_CREATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureRequest']
_UPDATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureRequest']
_DELETEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureRequest']
_LISTFEATUREHISTOGRAMSREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureHistogramsRequest']
_LISTFEATUREHISTOGRAMSRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureHistogramsResponse']
_GETFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureHistogramRequest']
_CREATEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureHistogramRequest']
_UPDATEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureHistogramRequest']
_DELETEFEATUREHISTOGRAMREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureHistogramRequest']
_LISTFEATUREPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturePipelinesRequest']
_LISTFEATUREPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturePipelinesResponse']
_GETFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRequest']
_CREATEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRequest']
_UPDATEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRequest']
_DELETEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRequest']
_LISTFEATUREPIPELINERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunsRequest']
_LISTFEATUREPIPELINERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunsResponse']
_GETFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunRequest']
_CREATEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunRequest']
_UPDATEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunRequest']
_DELETEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunRequest']
_LISTFEATURESETSREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesetsRequest']
_LISTFEATURESETSRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesetsResponse']
_GETFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturesetRequest']
_CREATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturesetRequest']
_UPDATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturesetRequest']
_DELETEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturesetRequest']
_LISTLABELINGPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListLabelingPipelinesRequest']
_LISTLABELINGPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListLabelingPipelinesResponse']
_GETLABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRequest']
_CREATELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRequest']
_UPDATELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRequest']
_DELETELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRequest']
_LISTLABELINGPIPELINERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunsRequest']
_LISTLABELINGPIPELINERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunsResponse']
_GETLABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunRequest']
_CREATELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunRequest']
_UPDATELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunRequest']
_DELETELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunRequest']
_LISTRECIPESREQUEST = DESCRIPTOR.message_types_by_name['ListRecipesRequest']
_LISTRECIPESRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipesResponse']
_GETRECIPEREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRequest']
_CREATERECIPEREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRequest']
_UPDATERECIPEREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRequest']
_DELETERECIPEREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRequest']
_LISTRECIPERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListRecipeRunsRequest']
_LISTRECIPERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipeRunsResponse']
_GETRECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRunRequest']
_CREATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRunRequest']
_UPDATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRunRequest']
_DELETERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRunRequest']
_LISTMODELAUTOBUILDERSREQUEST = DESCRIPTOR.message_types_by_name['ListModelAutobuildersRequest']
_LISTMODELAUTOBUILDERSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelAutobuildersResponse']
_GETMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['GetModelAutobuilderRequest']
_CREATEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['CreateModelAutobuilderRequest']
_UPDATEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderRequest']
_DELETEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderRequest']
_LISTMODELSREQUEST = DESCRIPTOR.message_types_by_name['ListModelsRequest']
_LISTMODELSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelsResponse']
_GETMODELREQUEST = DESCRIPTOR.message_types_by_name['GetModelRequest']
_CREATEMODELREQUEST = DESCRIPTOR.message_types_by_name['CreateModelRequest']
_UPDATEMODELREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelRequest']
_DELETEMODELREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelRequest']
_LISTMODELPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListModelPipelinesRequest']
_LISTMODELPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListModelPipelinesResponse']
_GETMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetModelPipelineRequest']
_CREATEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateModelPipelineRequest']
_UPDATEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelPipelineRequest']
_DELETEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelPipelineRequest']
_LISTMODELPIPELINERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListModelPipelineRunsRequest']
_LISTMODELPIPELINERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelPipelineRunsResponse']
_GETMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelPipelineRunRequest']
_CREATEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelPipelineRunRequest']
_UPDATEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelPipelineRunRequest']
_DELETEMODELPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelPipelineRunRequest']
_LISTNOTEBOOKSREQUEST = DESCRIPTOR.message_types_by_name['ListNotebooksRequest']
_LISTNOTEBOOKSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotebooksResponse']
_GETNOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['GetNotebookRequest']
_CREATENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateNotebookRequest']
_UPDATENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotebookRequest']
_DELETENOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotebookRequest']
_LISTNOTEBOOKRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListNotebookRunsRequest']
_LISTNOTEBOOKRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotebookRunsResponse']
_GETNOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['GetNotebookRunRequest']
_CREATENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateNotebookRunRequest']
_UPDATENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotebookRunRequest']
_DELETENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotebookRunRequest']
_LISTREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListReportsRequest']
_LISTREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListReportsResponse']
_GETREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetReportRequest']
_CREATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateReportRequest']
_UPDATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateReportRequest']
_DELETEREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteReportRequest']
_LISTCRONREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListCronReportsRequest']
_LISTCRONREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListCronReportsResponse']
_GETCRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetCronReportRequest']
_CREATECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateCronReportRequest']
_UPDATECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateCronReportRequest']
_DELETECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteCronReportRequest']
_LISTSTUDIESREQUEST = DESCRIPTOR.message_types_by_name['ListStudiesRequest']
_LISTSTUDIESRESPONSE = DESCRIPTOR.message_types_by_name['ListStudiesResponse']
_GETSTUDYREQUEST = DESCRIPTOR.message_types_by_name['GetStudyRequest']
_CREATESTUDYREQUEST = DESCRIPTOR.message_types_by_name['CreateStudyRequest']
_UPDATESTUDYREQUEST = DESCRIPTOR.message_types_by_name['UpdateStudyRequest']
_DELETESTUDYREQUEST = DESCRIPTOR.message_types_by_name['DeleteStudyRequest']
_LISTCRONPREDICTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListCronPredictionsRequest']
_LISTCRONPREDICTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListCronPredictionsResponse']
_GETCRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['GetCronPredictionRequest']
_CREATECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['CreateCronPredictionRequest']
_UPDATECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateCronPredictionRequest']
_DELETECRONPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteCronPredictionRequest']
_LISTCURTAINSREQUEST = DESCRIPTOR.message_types_by_name['ListCurtainsRequest']
_LISTCURTAINSRESPONSE = DESCRIPTOR.message_types_by_name['ListCurtainsResponse']
_GETCURTAINREQUEST = DESCRIPTOR.message_types_by_name['GetCurtainRequest']
_CREATECURTAINREQUEST = DESCRIPTOR.message_types_by_name['CreateCurtainRequest']
_UPDATECURTAINREQUEST = DESCRIPTOR.message_types_by_name['UpdateCurtainRequest']
_DELETECURTAINREQUEST = DESCRIPTOR.message_types_by_name['DeleteCurtainRequest']
_LISTPREDICTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictionsRequest']
_LISTPREDICTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictionsResponse']
_GETPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['GetPredictionRequest']
_CREATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictionRequest']
_UPDATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictionRequest']
_DELETEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictionRequest']
_LISTPREDICTORSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictorsRequest']
_LISTPREDICTORSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictorsResponse']
_GETPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['GetPredictorRequest']
_CREATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictorRequest']
_UPDATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictorRequest']
_DELETEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictorRequest']
_LISTREVIEWSREQUEST = DESCRIPTOR.message_types_by_name['ListReviewsRequest']
_LISTREVIEWSRESPONSE = DESCRIPTOR.message_types_by_name['ListReviewsResponse']
_GETREVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetReviewRequest']
_CREATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['CreateReviewRequest']
_UPDATEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['UpdateReviewRequest']
_DELETEREVIEWREQUEST = DESCRIPTOR.message_types_by_name['DeleteReviewRequest']
_LISTPOSTMORTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListPostMortemsRequest']
_LISTPOSTMORTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListPostMortemsResponse']
_GETPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['GetPostMortemRequest']
_CREATEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['CreatePostMortemRequest']
_UPDATEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdatePostMortemRequest']
_DELETEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['DeletePostMortemRequest']
_LISTRUNBOOKSREQUEST = DESCRIPTOR.message_types_by_name['ListRunbooksRequest']
_LISTRUNBOOKSRESPONSE = DESCRIPTOR.message_types_by_name['ListRunbooksResponse']
_GETRUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['GetRunbookRequest']
_CREATERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateRunbookRequest']
_UPDATERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateRunbookRequest']
_DELETERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['DeleteRunbookRequest']
_LISTSQLQUERYSREQUEST = DESCRIPTOR.message_types_by_name['ListSqlQuerysRequest']
_LISTSQLQUERYSRESPONSE = DESCRIPTOR.message_types_by_name['ListSqlQuerysResponse']
_GETSQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['GetSqlQueryRequest']
_CREATESQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['CreateSqlQueryRequest']
_UPDATESQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['UpdateSqlQueryRequest']
_DELETESQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['DeleteSqlQueryRequest']
_LISTSQLQUERYRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListSqlQueryRunsRequest']
_LISTSQLQUERYRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListSqlQueryRunsResponse']
_GETSQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['GetSqlQueryRunRequest']
_CREATESQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateSqlQueryRunRequest']
_UPDATESQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunRequest']
_DELETESQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunRequest']
_LISTWEBREQUESTSREQUEST = DESCRIPTOR.message_types_by_name['ListWebRequestsRequest']
_LISTWEBREQUESTSRESPONSE = DESCRIPTOR.message_types_by_name['ListWebRequestsResponse']
_GETWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['GetWebRequestRequest']
_CREATEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['CreateWebRequestRequest']
_UPDATEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebRequestRequest']
_DELETEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['DeleteWebRequestRequest']
_LISTWEBREQUESTRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListWebRequestRunsRequest']
_LISTWEBREQUESTRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListWebRequestRunsResponse']
_GETWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['GetWebRequestRunRequest']
_CREATEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateWebRequestRunRequest']
_UPDATEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebRequestRunRequest']
_DELETEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteWebRequestRunRequest']
_LISTDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['ListDataAppRequest']
_LISTDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['ListDataAppResponse']
_GETDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['GetDataAppRequest']
_CREATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['CreateDataAppRequest']
_UPDATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataAppRequest']
_DELETEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataAppRequest']
ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

DeleteAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest)
  })
_sym_db.RegisterMessage(DeleteAccountRequest)

ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

DeleteAlertRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest)
  })
_sym_db.RegisterMessage(DeleteAlertRequest)

ListAttachmentsRequest = _reflection.GeneratedProtocolMessageType('ListAttachmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTACHMENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsRequest)
  })
_sym_db.RegisterMessage(ListAttachmentsRequest)

ListAttachmentsResponse = _reflection.GeneratedProtocolMessageType('ListAttachmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTACHMENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAttachmentsResponse)
  })
_sym_db.RegisterMessage(ListAttachmentsResponse)

GetAttachmentRequest = _reflection.GeneratedProtocolMessageType('GetAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAttachmentRequest)
  })
_sym_db.RegisterMessage(GetAttachmentRequest)

CreateAttachmentRequest = _reflection.GeneratedProtocolMessageType('CreateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAttachmentRequest)
  })
_sym_db.RegisterMessage(CreateAttachmentRequest)

UpdateAttachmentRequest = _reflection.GeneratedProtocolMessageType('UpdateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAttachmentRequest)
  })
_sym_db.RegisterMessage(UpdateAttachmentRequest)

DeleteAttachmentRequest = _reflection.GeneratedProtocolMessageType('DeleteAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAttachmentRequest)
  })
_sym_db.RegisterMessage(DeleteAttachmentRequest)

ListTodosRequest = _reflection.GeneratedProtocolMessageType('ListTodosRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest)
  })
_sym_db.RegisterMessage(ListTodosRequest)

ListTodosResponse = _reflection.GeneratedProtocolMessageType('ListTodosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse)
  })
_sym_db.RegisterMessage(ListTodosResponse)

GetTodoRequest = _reflection.GeneratedProtocolMessageType('GetTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest)
  })
_sym_db.RegisterMessage(GetTodoRequest)

CreateTodoRequest = _reflection.GeneratedProtocolMessageType('CreateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest)
  })
_sym_db.RegisterMessage(CreateTodoRequest)

UpdateTodoRequest = _reflection.GeneratedProtocolMessageType('UpdateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest)
  })
_sym_db.RegisterMessage(UpdateTodoRequest)

DeleteTodoRequest = _reflection.GeneratedProtocolMessageType('DeleteTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest)
  })
_sym_db.RegisterMessage(DeleteTodoRequest)

ListMeetingsRequest = _reflection.GeneratedProtocolMessageType('ListMeetingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEETINGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListMeetingsRequest)
  })
_sym_db.RegisterMessage(ListMeetingsRequest)

ListMeetingsResponse = _reflection.GeneratedProtocolMessageType('ListMeetingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEETINGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListMeetingsResponse)
  })
_sym_db.RegisterMessage(ListMeetingsResponse)

GetMeetingRequest = _reflection.GeneratedProtocolMessageType('GetMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetMeetingRequest)
  })
_sym_db.RegisterMessage(GetMeetingRequest)

CreateMeetingRequest = _reflection.GeneratedProtocolMessageType('CreateMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateMeetingRequest)
  })
_sym_db.RegisterMessage(CreateMeetingRequest)

UpdateMeetingRequest = _reflection.GeneratedProtocolMessageType('UpdateMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateMeetingRequest)
  })
_sym_db.RegisterMessage(UpdateMeetingRequest)

DeleteMeetingRequest = _reflection.GeneratedProtocolMessageType('DeleteMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteMeetingRequest)
  })
_sym_db.RegisterMessage(DeleteMeetingRequest)

ListCommitsRequest = _reflection.GeneratedProtocolMessageType('ListCommitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest)
  })
_sym_db.RegisterMessage(ListCommitsRequest)

ListCommitsResponse = _reflection.GeneratedProtocolMessageType('ListCommitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse)
  })
_sym_db.RegisterMessage(ListCommitsResponse)

GetCommitRequest = _reflection.GeneratedProtocolMessageType('GetCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest)
  })
_sym_db.RegisterMessage(GetCommitRequest)

CreateCommitRequest = _reflection.GeneratedProtocolMessageType('CreateCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCommitRequest)
  })
_sym_db.RegisterMessage(CreateCommitRequest)

UpdateCommitRequest = _reflection.GeneratedProtocolMessageType('UpdateCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCommitRequest)
  })
_sym_db.RegisterMessage(UpdateCommitRequest)

DeleteCommitRequest = _reflection.GeneratedProtocolMessageType('DeleteCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest)
  })
_sym_db.RegisterMessage(DeleteCommitRequest)

ListApiTokensRequest = _reflection.GeneratedProtocolMessageType('ListApiTokensRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest)
  })
_sym_db.RegisterMessage(ListApiTokensRequest)

ListApiTokensResponse = _reflection.GeneratedProtocolMessageType('ListApiTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse)
  })
_sym_db.RegisterMessage(ListApiTokensResponse)

GetApiTokenRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest)
  })
_sym_db.RegisterMessage(GetApiTokenRequest)

CreateApiTokenRequest = _reflection.GeneratedProtocolMessageType('CreateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateApiTokenRequest)
  })
_sym_db.RegisterMessage(CreateApiTokenRequest)

UpdateApiTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateApiTokenRequest)
  })
_sym_db.RegisterMessage(UpdateApiTokenRequest)

DeleteApiTokenRequest = _reflection.GeneratedProtocolMessageType('DeleteApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest)
  })
_sym_db.RegisterMessage(DeleteApiTokenRequest)

ListConnectionsRequest = _reflection.GeneratedProtocolMessageType('ListConnectionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest)
  })
_sym_db.RegisterMessage(ListConnectionsRequest)

ListConnectionsResponse = _reflection.GeneratedProtocolMessageType('ListConnectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse)
  })
_sym_db.RegisterMessage(ListConnectionsResponse)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

CreateConnectionRequest = _reflection.GeneratedProtocolMessageType('CreateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest)
  })
_sym_db.RegisterMessage(CreateConnectionRequest)

UpdateConnectionRequest = _reflection.GeneratedProtocolMessageType('UpdateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest)
  })
_sym_db.RegisterMessage(UpdateConnectionRequest)

DeleteConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest)
  })
_sym_db.RegisterMessage(DeleteConnectionRequest)

ListLabsRequest = _reflection.GeneratedProtocolMessageType('ListLabsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest)
  })
_sym_db.RegisterMessage(ListLabsRequest)

ListLabsResponse = _reflection.GeneratedProtocolMessageType('ListLabsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse)
  })
_sym_db.RegisterMessage(ListLabsResponse)

GetLabRequest = _reflection.GeneratedProtocolMessageType('GetLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest)
  })
_sym_db.RegisterMessage(GetLabRequest)

CreateLabRequest = _reflection.GeneratedProtocolMessageType('CreateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest)
  })
_sym_db.RegisterMessage(CreateLabRequest)

UpdateLabRequest = _reflection.GeneratedProtocolMessageType('UpdateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest)
  })
_sym_db.RegisterMessage(UpdateLabRequest)

DeleteLabRequest = _reflection.GeneratedProtocolMessageType('DeleteLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest)
  })
_sym_db.RegisterMessage(DeleteLabRequest)

ListLicensesRequest = _reflection.GeneratedProtocolMessageType('ListLicensesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest)
  })
_sym_db.RegisterMessage(ListLicensesRequest)

ListLicensesResponse = _reflection.GeneratedProtocolMessageType('ListLicensesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse)
  })
_sym_db.RegisterMessage(ListLicensesResponse)

GetLicenseRequest = _reflection.GeneratedProtocolMessageType('GetLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest)
  })
_sym_db.RegisterMessage(GetLicenseRequest)

CreateLicenseRequest = _reflection.GeneratedProtocolMessageType('CreateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest)
  })
_sym_db.RegisterMessage(CreateLicenseRequest)

UpdateLicenseRequest = _reflection.GeneratedProtocolMessageType('UpdateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest)
  })
_sym_db.RegisterMessage(UpdateLicenseRequest)

DeleteLicenseRequest = _reflection.GeneratedProtocolMessageType('DeleteLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest)
  })
_sym_db.RegisterMessage(DeleteLicenseRequest)

ListNotifiersRequest = _reflection.GeneratedProtocolMessageType('ListNotifiersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest)
  })
_sym_db.RegisterMessage(ListNotifiersRequest)

ListNotifiersResponse = _reflection.GeneratedProtocolMessageType('ListNotifiersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse)
  })
_sym_db.RegisterMessage(ListNotifiersResponse)

GetNotifierRequest = _reflection.GeneratedProtocolMessageType('GetNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest)
  })
_sym_db.RegisterMessage(GetNotifierRequest)

CreateNotifierRequest = _reflection.GeneratedProtocolMessageType('CreateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest)
  })
_sym_db.RegisterMessage(CreateNotifierRequest)

UpdateNotifierRequest = _reflection.GeneratedProtocolMessageType('UpdateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest)
  })
_sym_db.RegisterMessage(UpdateNotifierRequest)

DeleteNotifierRequest = _reflection.GeneratedProtocolMessageType('DeleteNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest)
  })
_sym_db.RegisterMessage(DeleteNotifierRequest)

ListServingsitesRequest = _reflection.GeneratedProtocolMessageType('ListServingsitesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest)
  })
_sym_db.RegisterMessage(ListServingsitesRequest)

ListServingsitesResponse = _reflection.GeneratedProtocolMessageType('ListServingsitesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse)
  })
_sym_db.RegisterMessage(ListServingsitesResponse)

GetServingsiteRequest = _reflection.GeneratedProtocolMessageType('GetServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest)
  })
_sym_db.RegisterMessage(GetServingsiteRequest)

CreateServingsiteRequest = _reflection.GeneratedProtocolMessageType('CreateServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest)
  })
_sym_db.RegisterMessage(CreateServingsiteRequest)

UpdateServingsiteRequest = _reflection.GeneratedProtocolMessageType('UpdateServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest)
  })
_sym_db.RegisterMessage(UpdateServingsiteRequest)

DeleteServingsiteRequest = _reflection.GeneratedProtocolMessageType('DeleteServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest)
  })
_sym_db.RegisterMessage(DeleteServingsiteRequest)

ListTenantsRequest = _reflection.GeneratedProtocolMessageType('ListTenantsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest)
  })
_sym_db.RegisterMessage(ListTenantsRequest)

ListTenantsResponse = _reflection.GeneratedProtocolMessageType('ListTenantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse)
  })
_sym_db.RegisterMessage(ListTenantsResponse)

GetTenantRequest = _reflection.GeneratedProtocolMessageType('GetTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest)
  })
_sym_db.RegisterMessage(GetTenantRequest)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

UpdateTenantRequest = _reflection.GeneratedProtocolMessageType('UpdateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest)
  })
_sym_db.RegisterMessage(UpdateTenantRequest)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

ListVirtualBucketsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest)
  })
_sym_db.RegisterMessage(ListVirtualBucketsRequest)

ListVirtualBucketsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse)
  })
_sym_db.RegisterMessage(ListVirtualBucketsResponse)

GetVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('GetVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest)
  })
_sym_db.RegisterMessage(GetVirtualBucketRequest)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)

UpdateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketRequest)

DeleteVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketRequest)

ListVirtualClustersRequest = _reflection.GeneratedProtocolMessageType('ListVirtualClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest)
  })
_sym_db.RegisterMessage(ListVirtualClustersRequest)

ListVirtualClustersResponse = _reflection.GeneratedProtocolMessageType('ListVirtualClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse)
  })
_sym_db.RegisterMessage(ListVirtualClustersResponse)

GetVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('GetVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest)
  })
_sym_db.RegisterMessage(GetVirtualClusterRequest)

CreateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(CreateVirtualClusterRequest)

UpdateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualClusterRequest)

DeleteVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualClusterRequest)

ListVirtualVolumesRequest = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest)
  })
_sym_db.RegisterMessage(ListVirtualVolumesRequest)

ListVirtualVolumesResponse = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse)
  })
_sym_db.RegisterMessage(ListVirtualVolumesResponse)

GetVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('GetVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(GetVirtualVolumeRequest)

CreateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(CreateVirtualVolumeRequest)

UpdateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualVolumeRequest)

DeleteVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualVolumeRequest)

ListDataPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest)
  })
_sym_db.RegisterMessage(ListDataPipelinesRequest)

ListDataPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse)
  })
_sym_db.RegisterMessage(ListDataPipelinesResponse)

GetDataPipelineRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRequest)

CreateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRequest)

UpdateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRequest)

DeleteDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRequest)

ListDataPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunsRequest)

ListDataPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunsResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

ListDataProductsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest)
  })
_sym_db.RegisterMessage(ListDataProductsRequest)

ListDataProductsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse)
  })
_sym_db.RegisterMessage(ListDataProductsResponse)

GetDataProductRequest = _reflection.GeneratedProtocolMessageType('GetDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest)
  })
_sym_db.RegisterMessage(GetDataProductRequest)

CreateDataProductRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest)
  })
_sym_db.RegisterMessage(CreateDataProductRequest)

UpdateDataProductRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductRequest)

DeleteDataProductRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductRequest)

ListDataProductVersionsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest)
  })
_sym_db.RegisterMessage(ListDataProductVersionsRequest)

ListDataProductVersionsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse)
  })
_sym_db.RegisterMessage(ListDataProductVersionsResponse)

GetDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('GetDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest)
  })
_sym_db.RegisterMessage(GetDataProductVersionRequest)

CreateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(CreateDataProductVersionRequest)

UpdateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionRequest)

DeleteDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionRequest)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest)
  })
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse)
  })
_sym_db.RegisterMessage(ListDatasetsResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest)
  })
_sym_db.RegisterMessage(DeleteDatasetRequest)

ListDatasourcesRequest = _reflection.GeneratedProtocolMessageType('ListDatasourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest)
  })
_sym_db.RegisterMessage(ListDatasourcesRequest)

ListDatasourcesResponse = _reflection.GeneratedProtocolMessageType('ListDatasourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse)
  })
_sym_db.RegisterMessage(ListDatasourcesResponse)

GetDatasourceRequest = _reflection.GeneratedProtocolMessageType('GetDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest)
  })
_sym_db.RegisterMessage(GetDatasourceRequest)

CreateDatasourceRequest = _reflection.GeneratedProtocolMessageType('CreateDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest)
  })
_sym_db.RegisterMessage(CreateDatasourceRequest)

UpdateDatasourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest)
  })
_sym_db.RegisterMessage(UpdateDatasourceRequest)

DeleteDatasourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest)
  })
_sym_db.RegisterMessage(DeleteDatasourceRequest)

ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

GetEntityRequest = _reflection.GeneratedProtocolMessageType('GetEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest)
  })
_sym_db.RegisterMessage(GetEntityRequest)

CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

ListFeatureHistogramsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsRequest)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsRequest)

ListFeatureHistogramsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeatureHistogramsResponse)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsResponse)

GetFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('GetFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(GetFeatureHistogramRequest)

CreateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(CreateFeatureHistogramRequest)

UpdateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureHistogramRequest)

DeleteFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureHistogramRequest)

ListFeaturePipelinesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelinesRequest)

ListFeaturePipelinesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelinesResponse)

GetFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRequest)

CreateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRequest)

UpdateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRequest)

DeleteFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRequest)

ListFeaturePipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunsRequest)

ListFeaturePipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunsResponse)

GetFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunRequest)

CreateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunRequest)

UpdateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunRequest)

DeleteFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunRequest)

ListFeaturesetsRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest)
  })
_sym_db.RegisterMessage(ListFeaturesetsRequest)

ListFeaturesetsResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse)
  })
_sym_db.RegisterMessage(ListFeaturesetsResponse)

GetFeaturesetRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetRequest)

CreateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturesetRequest)
  })
_sym_db.RegisterMessage(CreateFeaturesetRequest)

UpdateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturesetRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturesetRequest)

DeleteFeaturesetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturesetRequest)

ListLabelingPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelinesRequest)

ListLabelingPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelinesResponse)

GetLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRequest)

CreateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRequest)

UpdateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRequest)

DeleteLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRequest)

ListLabelingPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunsRequest)

ListLabelingPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunsResponse)

GetLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunRequest)

CreateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunRequest)

UpdateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunRequest)

DeleteLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunRequest)

ListRecipesRequest = _reflection.GeneratedProtocolMessageType('ListRecipesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest)
  })
_sym_db.RegisterMessage(ListRecipesRequest)

ListRecipesResponse = _reflection.GeneratedProtocolMessageType('ListRecipesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse)
  })
_sym_db.RegisterMessage(ListRecipesResponse)

GetRecipeRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest)
  })
_sym_db.RegisterMessage(GetRecipeRequest)

CreateRecipeRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRequest)

UpdateRecipeRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRequest)

DeleteRecipeRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRequest)

ListRecipeRunsRequest = _reflection.GeneratedProtocolMessageType('ListRecipeRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest)
  })
_sym_db.RegisterMessage(ListRecipeRunsRequest)

ListRecipeRunsResponse = _reflection.GeneratedProtocolMessageType('ListRecipeRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse)
  })
_sym_db.RegisterMessage(ListRecipeRunsResponse)

GetRecipeRunRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest)
  })
_sym_db.RegisterMessage(GetRecipeRunRequest)

CreateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRunRequest)

UpdateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRunRequest)

DeleteRecipeRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRunRequest)

ListModelAutobuildersRequest = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest)
  })
_sym_db.RegisterMessage(ListModelAutobuildersRequest)

ListModelAutobuildersResponse = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse)
  })
_sym_db.RegisterMessage(ListModelAutobuildersResponse)

GetModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(GetModelAutobuilderRequest)

CreateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderRequest)

UpdateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderRequest)

DeleteModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

ListModelPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest)
  })
_sym_db.RegisterMessage(ListModelPipelinesRequest)

ListModelPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse)
  })
_sym_db.RegisterMessage(ListModelPipelinesResponse)

GetModelPipelineRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRequest)

CreateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRequest)

UpdateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRequest)

DeleteModelPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRequest)

ListModelPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsRequest)

ListModelPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsResponse)

GetModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRunRequest)

CreateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRunRequest)

UpdateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRunRequest)

DeleteModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRunRequest)

ListNotebooksRequest = _reflection.GeneratedProtocolMessageType('ListNotebooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest)
  })
_sym_db.RegisterMessage(ListNotebooksRequest)

ListNotebooksResponse = _reflection.GeneratedProtocolMessageType('ListNotebooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse)
  })
_sym_db.RegisterMessage(ListNotebooksResponse)

GetNotebookRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest)
  })
_sym_db.RegisterMessage(GetNotebookRequest)

CreateNotebookRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRequest)

UpdateNotebookRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRequest)

DeleteNotebookRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRequest)

ListNotebookRunsRequest = _reflection.GeneratedProtocolMessageType('ListNotebookRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest)
  })
_sym_db.RegisterMessage(ListNotebookRunsRequest)

ListNotebookRunsResponse = _reflection.GeneratedProtocolMessageType('ListNotebookRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse)
  })
_sym_db.RegisterMessage(ListNotebookRunsResponse)

GetNotebookRunRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest)
  })
_sym_db.RegisterMessage(GetNotebookRunRequest)

CreateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRunRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRunRequest)

UpdateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRunRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRunRequest)

DeleteNotebookRunRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRunRequest)

ListReportsRequest = _reflection.GeneratedProtocolMessageType('ListReportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest)
  })
_sym_db.RegisterMessage(ListReportsRequest)

ListReportsResponse = _reflection.GeneratedProtocolMessageType('ListReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse)
  })
_sym_db.RegisterMessage(ListReportsResponse)

GetReportRequest = _reflection.GeneratedProtocolMessageType('GetReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest)
  })
_sym_db.RegisterMessage(GetReportRequest)

CreateReportRequest = _reflection.GeneratedProtocolMessageType('CreateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest)
  })
_sym_db.RegisterMessage(CreateReportRequest)

UpdateReportRequest = _reflection.GeneratedProtocolMessageType('UpdateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest)
  })
_sym_db.RegisterMessage(UpdateReportRequest)

DeleteReportRequest = _reflection.GeneratedProtocolMessageType('DeleteReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest)
  })
_sym_db.RegisterMessage(DeleteReportRequest)

ListCronReportsRequest = _reflection.GeneratedProtocolMessageType('ListCronReportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest)
  })
_sym_db.RegisterMessage(ListCronReportsRequest)

ListCronReportsResponse = _reflection.GeneratedProtocolMessageType('ListCronReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse)
  })
_sym_db.RegisterMessage(ListCronReportsResponse)

GetCronReportRequest = _reflection.GeneratedProtocolMessageType('GetCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest)
  })
_sym_db.RegisterMessage(GetCronReportRequest)

CreateCronReportRequest = _reflection.GeneratedProtocolMessageType('CreateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronReportRequest)
  })
_sym_db.RegisterMessage(CreateCronReportRequest)

UpdateCronReportRequest = _reflection.GeneratedProtocolMessageType('UpdateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronReportRequest)
  })
_sym_db.RegisterMessage(UpdateCronReportRequest)

DeleteCronReportRequest = _reflection.GeneratedProtocolMessageType('DeleteCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest)
  })
_sym_db.RegisterMessage(DeleteCronReportRequest)

ListStudiesRequest = _reflection.GeneratedProtocolMessageType('ListStudiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest)
  })
_sym_db.RegisterMessage(ListStudiesRequest)

ListStudiesResponse = _reflection.GeneratedProtocolMessageType('ListStudiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse)
  })
_sym_db.RegisterMessage(ListStudiesResponse)

GetStudyRequest = _reflection.GeneratedProtocolMessageType('GetStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest)
  })
_sym_db.RegisterMessage(GetStudyRequest)

CreateStudyRequest = _reflection.GeneratedProtocolMessageType('CreateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest)
  })
_sym_db.RegisterMessage(CreateStudyRequest)

UpdateStudyRequest = _reflection.GeneratedProtocolMessageType('UpdateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest)
  })
_sym_db.RegisterMessage(UpdateStudyRequest)

DeleteStudyRequest = _reflection.GeneratedProtocolMessageType('DeleteStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest)
  })
_sym_db.RegisterMessage(DeleteStudyRequest)

ListCronPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListCronPredictionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest)
  })
_sym_db.RegisterMessage(ListCronPredictionsRequest)

ListCronPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListCronPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse)
  })
_sym_db.RegisterMessage(ListCronPredictionsResponse)

GetCronPredictionRequest = _reflection.GeneratedProtocolMessageType('GetCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest)
  })
_sym_db.RegisterMessage(GetCronPredictionRequest)

CreateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('CreateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronPredictionRequest)
  })
_sym_db.RegisterMessage(CreateCronPredictionRequest)

UpdateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('UpdateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronPredictionRequest)
  })
_sym_db.RegisterMessage(UpdateCronPredictionRequest)

DeleteCronPredictionRequest = _reflection.GeneratedProtocolMessageType('DeleteCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest)
  })
_sym_db.RegisterMessage(DeleteCronPredictionRequest)

ListCurtainsRequest = _reflection.GeneratedProtocolMessageType('ListCurtainsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest)
  })
_sym_db.RegisterMessage(ListCurtainsRequest)

ListCurtainsResponse = _reflection.GeneratedProtocolMessageType('ListCurtainsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse)
  })
_sym_db.RegisterMessage(ListCurtainsResponse)

GetCurtainRequest = _reflection.GeneratedProtocolMessageType('GetCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest)
  })
_sym_db.RegisterMessage(GetCurtainRequest)

CreateCurtainRequest = _reflection.GeneratedProtocolMessageType('CreateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCurtainRequest)
  })
_sym_db.RegisterMessage(CreateCurtainRequest)

UpdateCurtainRequest = _reflection.GeneratedProtocolMessageType('UpdateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCurtainRequest)
  })
_sym_db.RegisterMessage(UpdateCurtainRequest)

DeleteCurtainRequest = _reflection.GeneratedProtocolMessageType('DeleteCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest)
  })
_sym_db.RegisterMessage(DeleteCurtainRequest)

ListPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListPredictionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest)
  })
_sym_db.RegisterMessage(ListPredictionsRequest)

ListPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse)
  })
_sym_db.RegisterMessage(ListPredictionsResponse)

GetPredictionRequest = _reflection.GeneratedProtocolMessageType('GetPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest)
  })
_sym_db.RegisterMessage(GetPredictionRequest)

CreatePredictionRequest = _reflection.GeneratedProtocolMessageType('CreatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest)
  })
_sym_db.RegisterMessage(CreatePredictionRequest)

UpdatePredictionRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest)
  })
_sym_db.RegisterMessage(UpdatePredictionRequest)

DeletePredictionRequest = _reflection.GeneratedProtocolMessageType('DeletePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest)
  })
_sym_db.RegisterMessage(DeletePredictionRequest)

ListPredictorsRequest = _reflection.GeneratedProtocolMessageType('ListPredictorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest)
  })
_sym_db.RegisterMessage(ListPredictorsRequest)

ListPredictorsResponse = _reflection.GeneratedProtocolMessageType('ListPredictorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse)
  })
_sym_db.RegisterMessage(ListPredictorsResponse)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

CreatePredictorRequest = _reflection.GeneratedProtocolMessageType('CreatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest)
  })
_sym_db.RegisterMessage(CreatePredictorRequest)

UpdatePredictorRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest)
  })
_sym_db.RegisterMessage(UpdatePredictorRequest)

DeletePredictorRequest = _reflection.GeneratedProtocolMessageType('DeletePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest)
  })
_sym_db.RegisterMessage(DeletePredictorRequest)

ListReviewsRequest = _reflection.GeneratedProtocolMessageType('ListReviewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest)
  })
_sym_db.RegisterMessage(ListReviewsRequest)

ListReviewsResponse = _reflection.GeneratedProtocolMessageType('ListReviewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse)
  })
_sym_db.RegisterMessage(ListReviewsResponse)

GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)

ListPostMortemsRequest = _reflection.GeneratedProtocolMessageType('ListPostMortemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest)
  })
_sym_db.RegisterMessage(ListPostMortemsRequest)

ListPostMortemsResponse = _reflection.GeneratedProtocolMessageType('ListPostMortemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse)
  })
_sym_db.RegisterMessage(ListPostMortemsResponse)

GetPostMortemRequest = _reflection.GeneratedProtocolMessageType('GetPostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest)
  })
_sym_db.RegisterMessage(GetPostMortemRequest)

CreatePostMortemRequest = _reflection.GeneratedProtocolMessageType('CreatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest)
  })
_sym_db.RegisterMessage(CreatePostMortemRequest)

UpdatePostMortemRequest = _reflection.GeneratedProtocolMessageType('UpdatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest)
  })
_sym_db.RegisterMessage(UpdatePostMortemRequest)

DeletePostMortemRequest = _reflection.GeneratedProtocolMessageType('DeletePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest)
  })
_sym_db.RegisterMessage(DeletePostMortemRequest)

ListRunbooksRequest = _reflection.GeneratedProtocolMessageType('ListRunbooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest)
  })
_sym_db.RegisterMessage(ListRunbooksRequest)

ListRunbooksResponse = _reflection.GeneratedProtocolMessageType('ListRunbooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse)
  })
_sym_db.RegisterMessage(ListRunbooksResponse)

GetRunbookRequest = _reflection.GeneratedProtocolMessageType('GetRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest)
  })
_sym_db.RegisterMessage(GetRunbookRequest)

CreateRunbookRequest = _reflection.GeneratedProtocolMessageType('CreateRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest)
  })
_sym_db.RegisterMessage(CreateRunbookRequest)

UpdateRunbookRequest = _reflection.GeneratedProtocolMessageType('UpdateRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest)
  })
_sym_db.RegisterMessage(UpdateRunbookRequest)

DeleteRunbookRequest = _reflection.GeneratedProtocolMessageType('DeleteRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest)
  })
_sym_db.RegisterMessage(DeleteRunbookRequest)

ListSqlQuerysRequest = _reflection.GeneratedProtocolMessageType('ListSqlQuerysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQuerysRequest)
  })
_sym_db.RegisterMessage(ListSqlQuerysRequest)

ListSqlQuerysResponse = _reflection.GeneratedProtocolMessageType('ListSqlQuerysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQuerysResponse)
  })
_sym_db.RegisterMessage(ListSqlQuerysResponse)

GetSqlQueryRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetSqlQueryRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRequest)

CreateSqlQueryRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateSqlQueryRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRequest)

UpdateSqlQueryRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateSqlQueryRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRequest)

DeleteSqlQueryRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteSqlQueryRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRequest)

ListSqlQueryRunsRequest = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQueryRunsRequest)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsRequest)

ListSqlQueryRunsResponse = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListSqlQueryRunsResponse)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsResponse)

GetSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRunRequest)

CreateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunRequest)

UpdateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunRequest)

DeleteSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunRequest)

ListWebRequestsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestsRequest)

ListWebRequestsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestsResponse)

GetWebRequestRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetWebRequestRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRequest)

CreateWebRequestRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateWebRequestRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRequest)

UpdateWebRequestRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateWebRequestRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRequest)

DeleteWebRequestRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteWebRequestRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRequest)

ListWebRequestRunsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestRunsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestRunsRequest)

ListWebRequestRunsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListWebRequestRunsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestRunsResponse)

GetWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetWebRequestRunRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRunRequest)

CreateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRunRequest)

UpdateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunRequest)

DeleteWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteWebRequestRunRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunRequest)

ListDataAppRequest = _reflection.GeneratedProtocolMessageType('ListDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppRequest)
  })
_sym_db.RegisterMessage(ListDataAppRequest)

ListDataAppResponse = _reflection.GeneratedProtocolMessageType('ListDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataAppResponse)
  })
_sym_db.RegisterMessage(ListDataAppResponse)

GetDataAppRequest = _reflection.GeneratedProtocolMessageType('GetDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataAppRequest)
  })
_sym_db.RegisterMessage(GetDataAppRequest)

CreateDataAppRequest = _reflection.GeneratedProtocolMessageType('CreateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataAppRequest)
  })
_sym_db.RegisterMessage(CreateDataAppRequest)

UpdateDataAppRequest = _reflection.GeneratedProtocolMessageType('UpdateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataAppRequest)
  })
_sym_db.RegisterMessage(UpdateDataAppRequest)

DeleteDataAppRequest = _reflection.GeneratedProtocolMessageType('DeleteDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataAppRequest)
  })
_sym_db.RegisterMessage(DeleteDataAppRequest)

_DATABASEPROXYSERVICE = DESCRIPTOR.services_by_name['DatabaseProxyService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/dbproxyd/v1'
  _LISTACCOUNTSREQUEST._serialized_start=540
  _LISTACCOUNTSREQUEST._serialized_end=619
  _LISTACCOUNTSRESPONSE._serialized_start=621
  _LISTACCOUNTSRESPONSE._serialized_end=747
  _GETACCOUNTREQUEST._serialized_start=749
  _GETACCOUNTREQUEST._serialized_end=801
  _CREATEACCOUNTREQUEST._serialized_start=803
  _CREATEACCOUNTREQUEST._serialized_end=903
  _UPDATEACCOUNTREQUEST._serialized_start=905
  _UPDATEACCOUNTREQUEST._serialized_end=1005
  _DELETEACCOUNTREQUEST._serialized_start=1007
  _DELETEACCOUNTREQUEST._serialized_end=1062
  _LISTALERTSREQUEST._serialized_start=1064
  _LISTALERTSREQUEST._serialized_end=1141
  _LISTALERTSRESPONSE._serialized_start=1143
  _LISTALERTSRESPONSE._serialized_end=1265
  _GETALERTREQUEST._serialized_start=1267
  _GETALERTREQUEST._serialized_end=1317
  _CREATEALERTREQUEST._serialized_start=1319
  _CREATEALERTREQUEST._serialized_end=1415
  _UPDATEALERTREQUEST._serialized_start=1417
  _UPDATEALERTREQUEST._serialized_end=1513
  _DELETEALERTREQUEST._serialized_start=1515
  _DELETEALERTREQUEST._serialized_end=1568
  _LISTATTACHMENTSREQUEST._serialized_start=1570
  _LISTATTACHMENTSREQUEST._serialized_end=1652
  _LISTATTACHMENTSRESPONSE._serialized_start=1655
  _LISTATTACHMENTSRESPONSE._serialized_end=1787
  _GETATTACHMENTREQUEST._serialized_start=1789
  _GETATTACHMENTREQUEST._serialized_end=1844
  _CREATEATTACHMENTREQUEST._serialized_start=1846
  _CREATEATTACHMENTREQUEST._serialized_end=1952
  _UPDATEATTACHMENTREQUEST._serialized_start=1954
  _UPDATEATTACHMENTREQUEST._serialized_end=2060
  _DELETEATTACHMENTREQUEST._serialized_start=2062
  _DELETEATTACHMENTREQUEST._serialized_end=2120
  _LISTTODOSREQUEST._serialized_start=2122
  _LISTTODOSREQUEST._serialized_end=2198
  _LISTTODOSRESPONSE._serialized_start=2200
  _LISTTODOSRESPONSE._serialized_end=2319
  _GETTODOREQUEST._serialized_start=2321
  _GETTODOREQUEST._serialized_end=2370
  _CREATETODOREQUEST._serialized_start=2372
  _CREATETODOREQUEST._serialized_end=2465
  _UPDATETODOREQUEST._serialized_start=2467
  _UPDATETODOREQUEST._serialized_end=2560
  _DELETETODOREQUEST._serialized_start=2562
  _DELETETODOREQUEST._serialized_end=2614
  _LISTMEETINGSREQUEST._serialized_start=2616
  _LISTMEETINGSREQUEST._serialized_end=2695
  _LISTMEETINGSRESPONSE._serialized_start=2697
  _LISTMEETINGSRESPONSE._serialized_end=2822
  _GETMEETINGREQUEST._serialized_start=2824
  _GETMEETINGREQUEST._serialized_end=2876
  _CREATEMEETINGREQUEST._serialized_start=2878
  _CREATEMEETINGREQUEST._serialized_end=2977
  _UPDATEMEETINGREQUEST._serialized_start=2979
  _UPDATEMEETINGREQUEST._serialized_end=3078
  _DELETEMEETINGREQUEST._serialized_start=3080
  _DELETEMEETINGREQUEST._serialized_end=3135
  _LISTCOMMITSREQUEST._serialized_start=3137
  _LISTCOMMITSREQUEST._serialized_end=3215
  _LISTCOMMITSRESPONSE._serialized_start=3217
  _LISTCOMMITSRESPONSE._serialized_end=3341
  _GETCOMMITREQUEST._serialized_start=3343
  _GETCOMMITREQUEST._serialized_end=3394
  _CREATECOMMITREQUEST._serialized_start=3396
  _CREATECOMMITREQUEST._serialized_end=3494
  _UPDATECOMMITREQUEST._serialized_start=3496
  _UPDATECOMMITREQUEST._serialized_end=3594
  _DELETECOMMITREQUEST._serialized_start=3596
  _DELETECOMMITREQUEST._serialized_end=3650
  _LISTAPITOKENSREQUEST._serialized_start=3652
  _LISTAPITOKENSREQUEST._serialized_end=3732
  _LISTAPITOKENSRESPONSE._serialized_start=3735
  _LISTAPITOKENSRESPONSE._serialized_end=3863
  _GETAPITOKENREQUEST._serialized_start=3865
  _GETAPITOKENREQUEST._serialized_end=3918
  _CREATEAPITOKENREQUEST._serialized_start=3920
  _CREATEAPITOKENREQUEST._serialized_end=4022
  _UPDATEAPITOKENREQUEST._serialized_start=4024
  _UPDATEAPITOKENREQUEST._serialized_end=4126
  _DELETEAPITOKENREQUEST._serialized_start=4128
  _DELETEAPITOKENREQUEST._serialized_end=4184
  _LISTCONNECTIONSREQUEST._serialized_start=4186
  _LISTCONNECTIONSREQUEST._serialized_end=4268
  _LISTCONNECTIONSRESPONSE._serialized_start=4271
  _LISTCONNECTIONSRESPONSE._serialized_end=4403
  _GETCONNECTIONREQUEST._serialized_start=4405
  _GETCONNECTIONREQUEST._serialized_end=4460
  _CREATECONNECTIONREQUEST._serialized_start=4462
  _CREATECONNECTIONREQUEST._serialized_end=4568
  _UPDATECONNECTIONREQUEST._serialized_start=4570
  _UPDATECONNECTIONREQUEST._serialized_end=4676
  _DELETECONNECTIONREQUEST._serialized_start=4678
  _DELETECONNECTIONREQUEST._serialized_end=4736
  _LISTLABSREQUEST._serialized_start=4738
  _LISTLABSREQUEST._serialized_end=4813
  _LISTLABSRESPONSE._serialized_start=4815
  _LISTLABSRESPONSE._serialized_end=4933
  _GETLABREQUEST._serialized_start=4935
  _GETLABREQUEST._serialized_end=4983
  _CREATELABREQUEST._serialized_start=4985
  _CREATELABREQUEST._serialized_end=5077
  _UPDATELABREQUEST._serialized_start=5079
  _UPDATELABREQUEST._serialized_end=5171
  _DELETELABREQUEST._serialized_start=5173
  _DELETELABREQUEST._serialized_end=5224
  _LISTLICENSESREQUEST._serialized_start=5226
  _LISTLICENSESREQUEST._serialized_end=5305
  _LISTLICENSESRESPONSE._serialized_start=5307
  _LISTLICENSESRESPONSE._serialized_end=5433
  _GETLICENSEREQUEST._serialized_start=5435
  _GETLICENSEREQUEST._serialized_end=5487
  _CREATELICENSEREQUEST._serialized_start=5489
  _CREATELICENSEREQUEST._serialized_end=5589
  _UPDATELICENSEREQUEST._serialized_start=5591
  _UPDATELICENSEREQUEST._serialized_end=5691
  _DELETELICENSEREQUEST._serialized_start=5693
  _DELETELICENSEREQUEST._serialized_end=5748
  _LISTNOTIFIERSREQUEST._serialized_start=5750
  _LISTNOTIFIERSREQUEST._serialized_end=5830
  _LISTNOTIFIERSRESPONSE._serialized_start=5833
  _LISTNOTIFIERSRESPONSE._serialized_end=5961
  _GETNOTIFIERREQUEST._serialized_start=5963
  _GETNOTIFIERREQUEST._serialized_end=6016
  _CREATENOTIFIERREQUEST._serialized_start=6018
  _CREATENOTIFIERREQUEST._serialized_end=6120
  _UPDATENOTIFIERREQUEST._serialized_start=6122
  _UPDATENOTIFIERREQUEST._serialized_end=6224
  _DELETENOTIFIERREQUEST._serialized_start=6226
  _DELETENOTIFIERREQUEST._serialized_end=6282
  _LISTSERVINGSITESREQUEST._serialized_start=6284
  _LISTSERVINGSITESREQUEST._serialized_end=6367
  _LISTSERVINGSITESRESPONSE._serialized_start=6370
  _LISTSERVINGSITESRESPONSE._serialized_end=6504
  _GETSERVINGSITEREQUEST._serialized_start=6506
  _GETSERVINGSITEREQUEST._serialized_end=6562
  _CREATESERVINGSITEREQUEST._serialized_start=6564
  _CREATESERVINGSITEREQUEST._serialized_end=6672
  _UPDATESERVINGSITEREQUEST._serialized_start=6674
  _UPDATESERVINGSITEREQUEST._serialized_end=6782
  _DELETESERVINGSITEREQUEST._serialized_start=6784
  _DELETESERVINGSITEREQUEST._serialized_end=6843
  _LISTTENANTSREQUEST._serialized_start=6845
  _LISTTENANTSREQUEST._serialized_end=6923
  _LISTTENANTSRESPONSE._serialized_start=6925
  _LISTTENANTSRESPONSE._serialized_end=7049
  _GETTENANTREQUEST._serialized_start=7051
  _GETTENANTREQUEST._serialized_end=7102
  _CREATETENANTREQUEST._serialized_start=7104
  _CREATETENANTREQUEST._serialized_end=7202
  _UPDATETENANTREQUEST._serialized_start=7204
  _UPDATETENANTREQUEST._serialized_end=7302
  _DELETETENANTREQUEST._serialized_start=7304
  _DELETETENANTREQUEST._serialized_end=7358
  _LISTVIRTUALBUCKETSREQUEST._serialized_start=7360
  _LISTVIRTUALBUCKETSREQUEST._serialized_end=7445
  _LISTVIRTUALBUCKETSRESPONSE._serialized_start=7448
  _LISTVIRTUALBUCKETSRESPONSE._serialized_end=7586
  _GETVIRTUALBUCKETREQUEST._serialized_start=7588
  _GETVIRTUALBUCKETREQUEST._serialized_end=7646
  _CREATEVIRTUALBUCKETREQUEST._serialized_start=7648
  _CREATEVIRTUALBUCKETREQUEST._serialized_end=7760
  _UPDATEVIRTUALBUCKETREQUEST._serialized_start=7762
  _UPDATEVIRTUALBUCKETREQUEST._serialized_end=7874
  _DELETEVIRTUALBUCKETREQUEST._serialized_start=7876
  _DELETEVIRTUALBUCKETREQUEST._serialized_end=7937
  _LISTVIRTUALCLUSTERSREQUEST._serialized_start=7939
  _LISTVIRTUALCLUSTERSREQUEST._serialized_end=8025
  _LISTVIRTUALCLUSTERSRESPONSE._serialized_start=8028
  _LISTVIRTUALCLUSTERSRESPONSE._serialized_end=8168
  _GETVIRTUALCLUSTERREQUEST._serialized_start=8170
  _GETVIRTUALCLUSTERREQUEST._serialized_end=8229
  _CREATEVIRTUALCLUSTERREQUEST._serialized_start=8231
  _CREATEVIRTUALCLUSTERREQUEST._serialized_end=8345
  _UPDATEVIRTUALCLUSTERREQUEST._serialized_start=8347
  _UPDATEVIRTUALCLUSTERREQUEST._serialized_end=8461
  _DELETEVIRTUALCLUSTERREQUEST._serialized_start=8463
  _DELETEVIRTUALCLUSTERREQUEST._serialized_end=8525
  _LISTVIRTUALVOLUMESREQUEST._serialized_start=8527
  _LISTVIRTUALVOLUMESREQUEST._serialized_end=8612
  _LISTVIRTUALVOLUMESRESPONSE._serialized_start=8615
  _LISTVIRTUALVOLUMESRESPONSE._serialized_end=8753
  _GETVIRTUALVOLUMEREQUEST._serialized_start=8755
  _GETVIRTUALVOLUMEREQUEST._serialized_end=8813
  _CREATEVIRTUALVOLUMEREQUEST._serialized_start=8815
  _CREATEVIRTUALVOLUMEREQUEST._serialized_end=8927
  _UPDATEVIRTUALVOLUMEREQUEST._serialized_start=8929
  _UPDATEVIRTUALVOLUMEREQUEST._serialized_end=9041
  _DELETEVIRTUALVOLUMEREQUEST._serialized_start=9043
  _DELETEVIRTUALVOLUMEREQUEST._serialized_end=9104
  _LISTDATAPIPELINESREQUEST._serialized_start=9106
  _LISTDATAPIPELINESREQUEST._serialized_end=9190
  _LISTDATAPIPELINESRESPONSE._serialized_start=9193
  _LISTDATAPIPELINESRESPONSE._serialized_end=9328
  _GETDATAPIPELINEREQUEST._serialized_start=9330
  _GETDATAPIPELINEREQUEST._serialized_end=9387
  _CREATEDATAPIPELINEREQUEST._serialized_start=9389
  _CREATEDATAPIPELINEREQUEST._serialized_end=9498
  _UPDATEDATAPIPELINEREQUEST._serialized_start=9500
  _UPDATEDATAPIPELINEREQUEST._serialized_end=9609
  _DELETEDATAPIPELINEREQUEST._serialized_start=9611
  _DELETEDATAPIPELINEREQUEST._serialized_end=9671
  _LISTDATAPIPELINERUNSREQUEST._serialized_start=9673
  _LISTDATAPIPELINERUNSREQUEST._serialized_end=9760
  _LISTDATAPIPELINERUNSRESPONSE._serialized_start=9763
  _LISTDATAPIPELINERUNSRESPONSE._serialized_end=9904
  _GETDATAPIPELINERUNREQUEST._serialized_start=9906
  _GETDATAPIPELINERUNREQUEST._serialized_end=9966
  _CREATEDATAPIPELINERUNREQUEST._serialized_start=9968
  _CREATEDATAPIPELINERUNREQUEST._serialized_end=10083
  _UPDATEDATAPIPELINERUNREQUEST._serialized_start=10085
  _UPDATEDATAPIPELINERUNREQUEST._serialized_end=10200
  _DELETEDATAPIPELINERUNREQUEST._serialized_start=10202
  _DELETEDATAPIPELINERUNREQUEST._serialized_end=10265
  _LISTDATAPRODUCTSREQUEST._serialized_start=10267
  _LISTDATAPRODUCTSREQUEST._serialized_end=10350
  _LISTDATAPRODUCTSRESPONSE._serialized_start=10353
  _LISTDATAPRODUCTSRESPONSE._serialized_end=10486
  _GETDATAPRODUCTREQUEST._serialized_start=10488
  _GETDATAPRODUCTREQUEST._serialized_end=10544
  _CREATEDATAPRODUCTREQUEST._serialized_start=10546
  _CREATEDATAPRODUCTREQUEST._serialized_end=10653
  _UPDATEDATAPRODUCTREQUEST._serialized_start=10655
  _UPDATEDATAPRODUCTREQUEST._serialized_end=10762
  _DELETEDATAPRODUCTREQUEST._serialized_start=10764
  _DELETEDATAPRODUCTREQUEST._serialized_end=10823
  _LISTDATAPRODUCTVERSIONSREQUEST._serialized_start=10825
  _LISTDATAPRODUCTVERSIONSREQUEST._serialized_end=10915
  _LISTDATAPRODUCTVERSIONSRESPONSE._serialized_start=10918
  _LISTDATAPRODUCTVERSIONSRESPONSE._serialized_end=11065
  _GETDATAPRODUCTVERSIONREQUEST._serialized_start=11067
  _GETDATAPRODUCTVERSIONREQUEST._serialized_end=11130
  _CREATEDATAPRODUCTVERSIONREQUEST._serialized_start=11132
  _CREATEDATAPRODUCTVERSIONREQUEST._serialized_end=11253
  _UPDATEDATAPRODUCTVERSIONREQUEST._serialized_start=11255
  _UPDATEDATAPRODUCTVERSIONREQUEST._serialized_end=11376
  _DELETEDATAPRODUCTVERSIONREQUEST._serialized_start=11378
  _DELETEDATAPRODUCTVERSIONREQUEST._serialized_end=11444
  _LISTDATASETSREQUEST._serialized_start=11446
  _LISTDATASETSREQUEST._serialized_end=11525
  _LISTDATASETSRESPONSE._serialized_start=11527
  _LISTDATASETSRESPONSE._serialized_end=11652
  _GETDATASETREQUEST._serialized_start=11654
  _GETDATASETREQUEST._serialized_end=11706
  _CREATEDATASETREQUEST._serialized_start=11708
  _CREATEDATASETREQUEST._serialized_end=11807
  _UPDATEDATASETREQUEST._serialized_start=11809
  _UPDATEDATASETREQUEST._serialized_end=11908
  _DELETEDATASETREQUEST._serialized_start=11910
  _DELETEDATASETREQUEST._serialized_end=11965
  _LISTDATASOURCESREQUEST._serialized_start=11967
  _LISTDATASOURCESREQUEST._serialized_end=12049
  _LISTDATASOURCESRESPONSE._serialized_start=12052
  _LISTDATASOURCESRESPONSE._serialized_end=12183
  _GETDATASOURCEREQUEST._serialized_start=12185
  _GETDATASOURCEREQUEST._serialized_end=12240
  _CREATEDATASOURCEREQUEST._serialized_start=12242
  _CREATEDATASOURCEREQUEST._serialized_end=12347
  _UPDATEDATASOURCEREQUEST._serialized_start=12349
  _UPDATEDATASOURCEREQUEST._serialized_end=12454
  _DELETEDATASOURCEREQUEST._serialized_start=12456
  _DELETEDATASOURCEREQUEST._serialized_end=12514
  _LISTENTITIESREQUEST._serialized_start=12516
  _LISTENTITIESREQUEST._serialized_end=12595
  _LISTENTITIESRESPONSE._serialized_start=12597
  _LISTENTITIESRESPONSE._serialized_end=12721
  _GETENTITYREQUEST._serialized_start=12723
  _GETENTITYREQUEST._serialized_end=12774
  _CREATEENTITYREQUEST._serialized_start=12776
  _CREATEENTITYREQUEST._serialized_end=12873
  _UPDATEENTITYREQUEST._serialized_start=12875
  _UPDATEENTITYREQUEST._serialized_end=12972
  _DELETEENTITYREQUEST._serialized_start=12974
  _DELETEENTITYREQUEST._serialized_end=13028
  _LISTFEATURESREQUEST._serialized_start=13030
  _LISTFEATURESREQUEST._serialized_end=13109
  _LISTFEATURESRESPONSE._serialized_start=13111
  _LISTFEATURESRESPONSE._serialized_end=13236
  _GETFEATUREREQUEST._serialized_start=13238
  _GETFEATUREREQUEST._serialized_end=13290
  _CREATEFEATUREREQUEST._serialized_start=13292
  _CREATEFEATUREREQUEST._serialized_end=13391
  _UPDATEFEATUREREQUEST._serialized_start=13393
  _UPDATEFEATUREREQUEST._serialized_end=13492
  _DELETEFEATUREREQUEST._serialized_start=13494
  _DELETEFEATUREREQUEST._serialized_end=13549
  _LISTFEATUREHISTOGRAMSREQUEST._serialized_start=13551
  _LISTFEATUREHISTOGRAMSREQUEST._serialized_end=13639
  _LISTFEATUREHISTOGRAMSRESPONSE._serialized_start=13642
  _LISTFEATUREHISTOGRAMSRESPONSE._serialized_end=13785
  _GETFEATUREHISTOGRAMREQUEST._serialized_start=13787
  _GETFEATUREHISTOGRAMREQUEST._serialized_end=13848
  _CREATEFEATUREHISTOGRAMREQUEST._serialized_start=13850
  _CREATEFEATUREHISTOGRAMREQUEST._serialized_end=13967
  _UPDATEFEATUREHISTOGRAMREQUEST._serialized_start=13969
  _UPDATEFEATUREHISTOGRAMREQUEST._serialized_end=14086
  _DELETEFEATUREHISTOGRAMREQUEST._serialized_start=14088
  _DELETEFEATUREHISTOGRAMREQUEST._serialized_end=14152
  _LISTFEATUREPIPELINESREQUEST._serialized_start=14154
  _LISTFEATUREPIPELINESREQUEST._serialized_end=14241
  _LISTFEATUREPIPELINESRESPONSE._serialized_start=14244
  _LISTFEATUREPIPELINESRESPONSE._serialized_end=14385
  _GETFEATUREPIPELINEREQUEST._serialized_start=14387
  _GETFEATUREPIPELINEREQUEST._serialized_end=14447
  _CREATEFEATUREPIPELINEREQUEST._serialized_start=14449
  _CREATEFEATUREPIPELINEREQUEST._serialized_end=14564
  _UPDATEFEATUREPIPELINEREQUEST._serialized_start=14566
  _UPDATEFEATUREPIPELINEREQUEST._serialized_end=14681
  _DELETEFEATUREPIPELINEREQUEST._serialized_start=14683
  _DELETEFEATUREPIPELINEREQUEST._serialized_end=14746
  _LISTFEATUREPIPELINERUNSREQUEST._serialized_start=14748
  _LISTFEATUREPIPELINERUNSREQUEST._serialized_end=14838
  _LISTFEATUREPIPELINERUNSRESPONSE._serialized_start=14841
  _LISTFEATUREPIPELINERUNSRESPONSE._serialized_end=14988
  _GETFEATUREPIPELINERUNREQUEST._serialized_start=14990
  _GETFEATUREPIPELINERUNREQUEST._serialized_end=15053
  _CREATEFEATUREPIPELINERUNREQUEST._serialized_start=15055
  _CREATEFEATUREPIPELINERUNREQUEST._serialized_end=15176
  _UPDATEFEATUREPIPELINERUNREQUEST._serialized_start=15178
  _UPDATEFEATUREPIPELINERUNREQUEST._serialized_end=15299
  _DELETEFEATUREPIPELINERUNREQUEST._serialized_start=15301
  _DELETEFEATUREPIPELINERUNREQUEST._serialized_end=15367
  _LISTFEATURESETSREQUEST._serialized_start=15369
  _LISTFEATURESETSREQUEST._serialized_end=15451
  _LISTFEATURESETSRESPONSE._serialized_start=15454
  _LISTFEATURESETSRESPONSE._serialized_end=15585
  _GETFEATURESETREQUEST._serialized_start=15587
  _GETFEATURESETREQUEST._serialized_end=15642
  _CREATEFEATURESETREQUEST._serialized_start=15644
  _CREATEFEATURESETREQUEST._serialized_end=15749
  _UPDATEFEATURESETREQUEST._serialized_start=15751
  _UPDATEFEATURESETREQUEST._serialized_end=15856
  _DELETEFEATURESETREQUEST._serialized_start=15858
  _DELETEFEATURESETREQUEST._serialized_end=15916
  _LISTLABELINGPIPELINESREQUEST._serialized_start=15918
  _LISTLABELINGPIPELINESREQUEST._serialized_end=16006
  _LISTLABELINGPIPELINESRESPONSE._serialized_start=16009
  _LISTLABELINGPIPELINESRESPONSE._serialized_end=16152
  _GETLABELINGPIPELINEREQUEST._serialized_start=16154
  _GETLABELINGPIPELINEREQUEST._serialized_end=16215
  _CREATELABELINGPIPELINEREQUEST._serialized_start=16217
  _CREATELABELINGPIPELINEREQUEST._serialized_end=16334
  _UPDATELABELINGPIPELINEREQUEST._serialized_start=16336
  _UPDATELABELINGPIPELINEREQUEST._serialized_end=16453
  _DELETELABELINGPIPELINEREQUEST._serialized_start=16455
  _DELETELABELINGPIPELINEREQUEST._serialized_end=16519
  _LISTLABELINGPIPELINERUNSREQUEST._serialized_start=16521
  _LISTLABELINGPIPELINERUNSREQUEST._serialized_end=16612
  _LISTLABELINGPIPELINERUNSRESPONSE._serialized_start=16615
  _LISTLABELINGPIPELINERUNSRESPONSE._serialized_end=16764
  _GETLABELINGPIPELINERUNREQUEST._serialized_start=16766
  _GETLABELINGPIPELINERUNREQUEST._serialized_end=16830
  _CREATELABELINGPIPELINERUNREQUEST._serialized_start=16832
  _CREATELABELINGPIPELINERUNREQUEST._serialized_end=16955
  _UPDATELABELINGPIPELINERUNREQUEST._serialized_start=16957
  _UPDATELABELINGPIPELINERUNREQUEST._serialized_end=17080
  _DELETELABELINGPIPELINERUNREQUEST._serialized_start=17082
  _DELETELABELINGPIPELINERUNREQUEST._serialized_end=17149
  _LISTRECIPESREQUEST._serialized_start=17151
  _LISTRECIPESREQUEST._serialized_end=17229
  _LISTRECIPESRESPONSE._serialized_start=17231
  _LISTRECIPESRESPONSE._serialized_end=17354
  _GETRECIPEREQUEST._serialized_start=17356
  _GETRECIPEREQUEST._serialized_end=17407
  _CREATERECIPEREQUEST._serialized_start=17409
  _CREATERECIPEREQUEST._serialized_end=17506
  _UPDATERECIPEREQUEST._serialized_start=17508
  _UPDATERECIPEREQUEST._serialized_end=17605
  _DELETERECIPEREQUEST._serialized_start=17607
  _DELETERECIPEREQUEST._serialized_end=17661
  _LISTRECIPERUNSREQUEST._serialized_start=17663
  _LISTRECIPERUNSREQUEST._serialized_end=17744
  _LISTRECIPERUNSRESPONSE._serialized_start=17747
  _LISTRECIPERUNSRESPONSE._serialized_end=17876
  _GETRECIPERUNREQUEST._serialized_start=17878
  _GETRECIPERUNREQUEST._serialized_end=17932
  _CREATERECIPERUNREQUEST._serialized_start=17934
  _CREATERECIPERUNREQUEST._serialized_end=18037
  _UPDATERECIPERUNREQUEST._serialized_start=18039
  _UPDATERECIPERUNREQUEST._serialized_end=18142
  _DELETERECIPERUNREQUEST._serialized_start=18144
  _DELETERECIPERUNREQUEST._serialized_end=18201
  _LISTMODELAUTOBUILDERSREQUEST._serialized_start=18203
  _LISTMODELAUTOBUILDERSREQUEST._serialized_end=18291
  _LISTMODELAUTOBUILDERSRESPONSE._serialized_start=18294
  _LISTMODELAUTOBUILDERSRESPONSE._serialized_end=18441
  _GETMODELAUTOBUILDERREQUEST._serialized_start=18443
  _GETMODELAUTOBUILDERREQUEST._serialized_end=18504
  _CREATEMODELAUTOBUILDERREQUEST._serialized_start=18506
  _CREATEMODELAUTOBUILDERREQUEST._serialized_end=18627
  _UPDATEMODELAUTOBUILDERREQUEST._serialized_start=18629
  _UPDATEMODELAUTOBUILDERREQUEST._serialized_end=18750
  _DELETEMODELAUTOBUILDERREQUEST._serialized_start=18752
  _DELETEMODELAUTOBUILDERREQUEST._serialized_end=18816
  _LISTMODELSREQUEST._serialized_start=18818
  _LISTMODELSREQUEST._serialized_end=18895
  _LISTMODELSRESPONSE._serialized_start=18897
  _LISTMODELSRESPONSE._serialized_end=19022
  _GETMODELREQUEST._serialized_start=19024
  _GETMODELREQUEST._serialized_end=19074
  _CREATEMODELREQUEST._serialized_start=19076
  _CREATEMODELREQUEST._serialized_end=19175
  _UPDATEMODELREQUEST._serialized_start=19177
  _UPDATEMODELREQUEST._serialized_end=19276
  _DELETEMODELREQUEST._serialized_start=19278
  _DELETEMODELREQUEST._serialized_end=19331
  _LISTMODELPIPELINESREQUEST._serialized_start=19333
  _LISTMODELPIPELINESREQUEST._serialized_end=19418
  _LISTMODELPIPELINESRESPONSE._serialized_start=19421
  _LISTMODELPIPELINESRESPONSE._serialized_end=19562
  _GETMODELPIPELINEREQUEST._serialized_start=19564
  _GETMODELPIPELINEREQUEST._serialized_end=19622
  _CREATEMODELPIPELINEREQUEST._serialized_start=19624
  _CREATEMODELPIPELINEREQUEST._serialized_end=19739
  _UPDATEMODELPIPELINEREQUEST._serialized_start=19741
  _UPDATEMODELPIPELINEREQUEST._serialized_end=19856
  _DELETEMODELPIPELINEREQUEST._serialized_start=19858
  _DELETEMODELPIPELINEREQUEST._serialized_end=19919
  _LISTMODELPIPELINERUNSREQUEST._serialized_start=19921
  _LISTMODELPIPELINERUNSREQUEST._serialized_end=20009
  _LISTMODELPIPELINERUNSRESPONSE._serialized_start=20012
  _LISTMODELPIPELINERUNSRESPONSE._serialized_end=20159
  _GETMODELPIPELINERUNREQUEST._serialized_start=20161
  _GETMODELPIPELINERUNREQUEST._serialized_end=20222
  _CREATEMODELPIPELINERUNREQUEST._serialized_start=20224
  _CREATEMODELPIPELINERUNREQUEST._serialized_end=20345
  _UPDATEMODELPIPELINERUNREQUEST._serialized_start=20347
  _UPDATEMODELPIPELINERUNREQUEST._serialized_end=20468
  _DELETEMODELPIPELINERUNREQUEST._serialized_start=20470
  _DELETEMODELPIPELINERUNREQUEST._serialized_end=20534
  _LISTNOTEBOOKSREQUEST._serialized_start=20536
  _LISTNOTEBOOKSREQUEST._serialized_end=20616
  _LISTNOTEBOOKSRESPONSE._serialized_start=20619
  _LISTNOTEBOOKSRESPONSE._serialized_end=20750
  _GETNOTEBOOKREQUEST._serialized_start=20752
  _GETNOTEBOOKREQUEST._serialized_end=20805
  _CREATENOTEBOOKREQUEST._serialized_start=20807
  _CREATENOTEBOOKREQUEST._serialized_end=20912
  _UPDATENOTEBOOKREQUEST._serialized_start=20914
  _UPDATENOTEBOOKREQUEST._serialized_end=21019
  _DELETENOTEBOOKREQUEST._serialized_start=21021
  _DELETENOTEBOOKREQUEST._serialized_end=21077
  _LISTNOTEBOOKRUNSREQUEST._serialized_start=21079
  _LISTNOTEBOOKRUNSREQUEST._serialized_end=21162
  _LISTNOTEBOOKRUNSRESPONSE._serialized_start=21165
  _LISTNOTEBOOKRUNSRESPONSE._serialized_end=21302
  _GETNOTEBOOKRUNREQUEST._serialized_start=21304
  _GETNOTEBOOKRUNREQUEST._serialized_end=21360
  _CREATENOTEBOOKRUNREQUEST._serialized_start=21362
  _CREATENOTEBOOKRUNREQUEST._serialized_end=21473
  _UPDATENOTEBOOKRUNREQUEST._serialized_start=21475
  _UPDATENOTEBOOKRUNREQUEST._serialized_end=21586
  _DELETENOTEBOOKRUNREQUEST._serialized_start=21588
  _DELETENOTEBOOKRUNREQUEST._serialized_end=21647
  _LISTREPORTSREQUEST._serialized_start=21649
  _LISTREPORTSREQUEST._serialized_end=21727
  _LISTREPORTSRESPONSE._serialized_start=21729
  _LISTREPORTSRESPONSE._serialized_end=21856
  _GETREPORTREQUEST._serialized_start=21858
  _GETREPORTREQUEST._serialized_end=21909
  _CREATEREPORTREQUEST._serialized_start=21911
  _CREATEREPORTREQUEST._serialized_end=22012
  _UPDATEREPORTREQUEST._serialized_start=22014
  _UPDATEREPORTREQUEST._serialized_end=22115
  _DELETEREPORTREQUEST._serialized_start=22117
  _DELETEREPORTREQUEST._serialized_end=22171
  _LISTCRONREPORTSREQUEST._serialized_start=22173
  _LISTCRONREPORTSREQUEST._serialized_end=22255
  _LISTCRONREPORTSRESPONSE._serialized_start=22258
  _LISTCRONREPORTSRESPONSE._serialized_end=22393
  _GETCRONREPORTREQUEST._serialized_start=22395
  _GETCRONREPORTREQUEST._serialized_end=22450
  _CREATECRONREPORTREQUEST._serialized_start=22452
  _CREATECRONREPORTREQUEST._serialized_end=22561
  _UPDATECRONREPORTREQUEST._serialized_start=22563
  _UPDATECRONREPORTREQUEST._serialized_end=22672
  _DELETECRONREPORTREQUEST._serialized_start=22674
  _DELETECRONREPORTREQUEST._serialized_end=22732
  _LISTSTUDIESREQUEST._serialized_start=22734
  _LISTSTUDIESREQUEST._serialized_end=22812
  _LISTSTUDIESRESPONSE._serialized_start=22814
  _LISTSTUDIESRESPONSE._serialized_end=22940
  _GETSTUDYREQUEST._serialized_start=22942
  _GETSTUDYREQUEST._serialized_end=22992
  _CREATESTUDYREQUEST._serialized_start=22994
  _CREATESTUDYREQUEST._serialized_end=23093
  _UPDATESTUDYREQUEST._serialized_start=23095
  _UPDATESTUDYREQUEST._serialized_end=23194
  _DELETESTUDYREQUEST._serialized_start=23196
  _DELETESTUDYREQUEST._serialized_end=23249
  _LISTCRONPREDICTIONSREQUEST._serialized_start=23251
  _LISTCRONPREDICTIONSREQUEST._serialized_end=23337
  _LISTCRONPREDICTIONSRESPONSE._serialized_start=23340
  _LISTCRONPREDICTIONSRESPONSE._serialized_end=23484
  _GETCRONPREDICTIONREQUEST._serialized_start=23486
  _GETCRONPREDICTIONREQUEST._serialized_end=23545
  _CREATECRONPREDICTIONREQUEST._serialized_start=23547
  _CREATECRONPREDICTIONREQUEST._serialized_end=23665
  _UPDATECRONPREDICTIONREQUEST._serialized_start=23667
  _UPDATECRONPREDICTIONREQUEST._serialized_end=23785
  _DELETECRONPREDICTIONREQUEST._serialized_start=23787
  _DELETECRONPREDICTIONREQUEST._serialized_end=23849
  _LISTCURTAINSREQUEST._serialized_start=23851
  _LISTCURTAINSREQUEST._serialized_end=23930
  _LISTCURTAINSRESPONSE._serialized_start=23933
  _LISTCURTAINSRESPONSE._serialized_end=24063
  _GETCURTAINREQUEST._serialized_start=24065
  _GETCURTAINREQUEST._serialized_end=24117
  _CREATECURTAINREQUEST._serialized_start=24119
  _CREATECURTAINREQUEST._serialized_end=24223
  _UPDATECURTAINREQUEST._serialized_start=24225
  _UPDATECURTAINREQUEST._serialized_end=24329
  _DELETECURTAINREQUEST._serialized_start=24331
  _DELETECURTAINREQUEST._serialized_end=24386
  _LISTPREDICTIONSREQUEST._serialized_start=24388
  _LISTPREDICTIONSREQUEST._serialized_end=24470
  _LISTPREDICTIONSRESPONSE._serialized_start=24473
  _LISTPREDICTIONSRESPONSE._serialized_end=24609
  _GETPREDICTIONREQUEST._serialized_start=24611
  _GETPREDICTIONREQUEST._serialized_end=24666
  _CREATEPREDICTIONREQUEST._serialized_start=24668
  _CREATEPREDICTIONREQUEST._serialized_end=24778
  _UPDATEPREDICTIONREQUEST._serialized_start=24780
  _UPDATEPREDICTIONREQUEST._serialized_end=24890
  _DELETEPREDICTIONREQUEST._serialized_start=24892
  _DELETEPREDICTIONREQUEST._serialized_end=24950
  _LISTPREDICTORSREQUEST._serialized_start=24952
  _LISTPREDICTORSREQUEST._serialized_end=25033
  _LISTPREDICTORSRESPONSE._serialized_start=25036
  _LISTPREDICTORSRESPONSE._serialized_end=25170
  _GETPREDICTORREQUEST._serialized_start=25172
  _GETPREDICTORREQUEST._serialized_end=25226
  _CREATEPREDICTORREQUEST._serialized_start=25228
  _CREATEPREDICTORREQUEST._serialized_end=25336
  _UPDATEPREDICTORREQUEST._serialized_start=25338
  _UPDATEPREDICTORREQUEST._serialized_end=25446
  _DELETEPREDICTORREQUEST._serialized_start=25448
  _DELETEPREDICTORREQUEST._serialized_end=25505
  _LISTREVIEWSREQUEST._serialized_start=25507
  _LISTREVIEWSREQUEST._serialized_end=25585
  _LISTREVIEWSRESPONSE._serialized_start=25587
  _LISTREVIEWSRESPONSE._serialized_end=25710
  _GETREVIEWREQUEST._serialized_start=25712
  _GETREVIEWREQUEST._serialized_end=25763
  _CREATEREVIEWREQUEST._serialized_start=25765
  _CREATEREVIEWREQUEST._serialized_end=25862
  _UPDATEREVIEWREQUEST._serialized_start=25864
  _UPDATEREVIEWREQUEST._serialized_end=25961
  _DELETEREVIEWREQUEST._serialized_start=25963
  _DELETEREVIEWREQUEST._serialized_end=26017
  _LISTPOSTMORTEMSREQUEST._serialized_start=26019
  _LISTPOSTMORTEMSREQUEST._serialized_end=26101
  _LISTPOSTMORTEMSRESPONSE._serialized_start=26104
  _LISTPOSTMORTEMSRESPONSE._serialized_end=26235
  _GETPOSTMORTEMREQUEST._serialized_start=26237
  _GETPOSTMORTEMREQUEST._serialized_end=26292
  _CREATEPOSTMORTEMREQUEST._serialized_start=26294
  _CREATEPOSTMORTEMREQUEST._serialized_end=26399
  _UPDATEPOSTMORTEMREQUEST._serialized_start=26401
  _UPDATEPOSTMORTEMREQUEST._serialized_end=26506
  _DELETEPOSTMORTEMREQUEST._serialized_start=26508
  _DELETEPOSTMORTEMREQUEST._serialized_end=26566
  _LISTRUNBOOKSREQUEST._serialized_start=26568
  _LISTRUNBOOKSREQUEST._serialized_end=26647
  _LISTRUNBOOKSRESPONSE._serialized_start=26649
  _LISTRUNBOOKSRESPONSE._serialized_end=26774
  _GETRUNBOOKREQUEST._serialized_start=26776
  _GETRUNBOOKREQUEST._serialized_end=26828
  _CREATERUNBOOKREQUEST._serialized_start=26830
  _CREATERUNBOOKREQUEST._serialized_end=26929
  _UPDATERUNBOOKREQUEST._serialized_start=26931
  _UPDATERUNBOOKREQUEST._serialized_end=27030
  _DELETERUNBOOKREQUEST._serialized_start=27032
  _DELETERUNBOOKREQUEST._serialized_end=27087
  _LISTSQLQUERYSREQUEST._serialized_start=27089
  _LISTSQLQUERYSREQUEST._serialized_end=27169
  _LISTSQLQUERYSRESPONSE._serialized_start=27171
  _LISTSQLQUERYSRESPONSE._serialized_end=27298
  _GETSQLQUERYREQUEST._serialized_start=27300
  _GETSQLQUERYREQUEST._serialized_end=27353
  _CREATESQLQUERYREQUEST._serialized_start=27355
  _CREATESQLQUERYREQUEST._serialized_end=27456
  _UPDATESQLQUERYREQUEST._serialized_start=27458
  _UPDATESQLQUERYREQUEST._serialized_end=27559
  _DELETESQLQUERYREQUEST._serialized_start=27561
  _DELETESQLQUERYREQUEST._serialized_end=27617
  _LISTSQLQUERYRUNSREQUEST._serialized_start=27619
  _LISTSQLQUERYRUNSREQUEST._serialized_end=27702
  _LISTSQLQUERYRUNSRESPONSE._serialized_start=27705
  _LISTSQLQUERYRUNSRESPONSE._serialized_end=27838
  _GETSQLQUERYRUNREQUEST._serialized_start=27840
  _GETSQLQUERYRUNREQUEST._serialized_end=27896
  _CREATESQLQUERYRUNREQUEST._serialized_start=27898
  _CREATESQLQUERYRUNREQUEST._serialized_end=28005
  _UPDATESQLQUERYRUNREQUEST._serialized_start=28007
  _UPDATESQLQUERYRUNREQUEST._serialized_end=28114
  _DELETESQLQUERYRUNREQUEST._serialized_start=28116
  _DELETESQLQUERYRUNREQUEST._serialized_end=28175
  _LISTWEBREQUESTSREQUEST._serialized_start=28177
  _LISTWEBREQUESTSREQUEST._serialized_end=28259
  _LISTWEBREQUESTSRESPONSE._serialized_start=28262
  _LISTWEBREQUESTSRESPONSE._serialized_end=28393
  _GETWEBREQUESTREQUEST._serialized_start=28395
  _GETWEBREQUESTREQUEST._serialized_end=28450
  _CREATEWEBREQUESTREQUEST._serialized_start=28452
  _CREATEWEBREQUESTREQUEST._serialized_end=28557
  _UPDATEWEBREQUESTREQUEST._serialized_start=28559
  _UPDATEWEBREQUESTREQUEST._serialized_end=28664
  _DELETEWEBREQUESTREQUEST._serialized_start=28666
  _DELETEWEBREQUESTREQUEST._serialized_end=28724
  _LISTWEBREQUESTRUNSREQUEST._serialized_start=28726
  _LISTWEBREQUESTRUNSREQUEST._serialized_end=28811
  _LISTWEBREQUESTRUNSRESPONSE._serialized_start=28814
  _LISTWEBREQUESTRUNSRESPONSE._serialized_end=28951
  _GETWEBREQUESTRUNREQUEST._serialized_start=28953
  _GETWEBREQUESTRUNREQUEST._serialized_end=29011
  _CREATEWEBREQUESTRUNREQUEST._serialized_start=29013
  _CREATEWEBREQUESTRUNREQUEST._serialized_end=29124
  _UPDATEWEBREQUESTRUNREQUEST._serialized_start=29126
  _UPDATEWEBREQUESTRUNREQUEST._serialized_end=29237
  _DELETEWEBREQUESTRUNREQUEST._serialized_start=29239
  _DELETEWEBREQUESTRUNREQUEST._serialized_end=29300
  _LISTDATAAPPREQUEST._serialized_start=29302
  _LISTDATAAPPREQUEST._serialized_end=29380
  _LISTDATAAPPRESPONSE._serialized_start=29383
  _LISTDATAAPPRESPONSE._serialized_end=29512
  _GETDATAAPPREQUEST._serialized_start=29514
  _GETDATAAPPREQUEST._serialized_end=29566
  _CREATEDATAAPPREQUEST._serialized_start=29568
  _CREATEDATAAPPREQUEST._serialized_end=29672
  _UPDATEDATAAPPREQUEST._serialized_start=29674
  _UPDATEDATAAPPREQUEST._serialized_end=29778
  _DELETEDATAAPPREQUEST._serialized_start=29780
  _DELETEDATAAPPREQUEST._serialized_end=29835
  _DATABASEPROXYSERVICE._serialized_start=29839
  _DATABASEPROXYSERVICE._serialized_end=71956
# @@protoc_insertion_point(module_scope)
